library(Seurat)
library(openxlsx)
library(readxl)
library(tidyr)
library("RColorBrewer")
library(dplyr)
library(reshape2)
library(fgsea)
library(patchwork)
library(presto)
library(ggplot2)
library(matrixStats)
library(fmsb)

cluster_dir <- "/beegfs/scratch/ric.squadrito/ric.squadrito/90-856756828_scRNAseq_Notaro/Analysis_MM3/results2"

wdir <- paste0(cluster_dir, "/Result2_MNOT")
ldir <- paste0(cluster_dir, "/Liver_APCs/")
pdir <- paste0(cluster_dir, "/Result2_MNOT/Plots")


# Custom functions
#PlotStellare <-readRDS(paste0(username,"Dropbox (HSR Global)/CancerGeneTherapy/Cancer Gene Therapy/MS/Notaro et al/Scripts/Functions/PlotStellare.rds"))
source(file = "/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/Analysis_MM/last_scripts_MNOT/TAD018/plot_stellare_function.R")

#############################################################################
##########################LIVER MACS ANALYSIS################################
#############################################################################
apcs.liver <- readRDS(paste0(ldir, "Liver_APCs_final.rds"))

#assign groups   
#name and order groups
apcs.liver@meta.data$RNA_Group[apcs.liver@meta.data$PROP.Condition=="li.OVA"] <- "liOVA"
apcs.liver@meta.data$RNA_Group[apcs.liver@meta.data$PROP.Condition=="li.OVA.Combo"] <- "OVA.Combo"
apcs.liver@meta.data$RNA_Group[apcs.liver@meta.data$PROP.Condition=="li.Stop"] <- "SIINFEKL"
apcs.liver@meta.data$RNA_Group[apcs.liver@meta.data$PROP.Condition=="li.Stop.Combo"] <- "SIINFEKL.Combo"
apcs.liver@meta.data$RNA_Group <- factor(x = apcs.liver@meta.data$RNA_Group, levels = c("liOVA", "OVA.Combo","SIINFEKL", "SIINFEKL.Combo"))
apcs.liver@meta.data$Tissue <- "Liver"


#######Figure S4L- PLOT STELLARE################
features1 <- c("H2-Q7", "H2-T22", "H2-Q4", "H2-K1", "H2-T23", "H2-M3", "H2-D1","Tap1","Tap2", #MHCI
              "H2-Eb1", "H2-Ab1", "H2-Aa", "H2-DMb1", "H2-DMa", "Ciita", #MHCII
              "Ifi44", "Oasl1","Irf7","Isg15", "Isg20","Oas1a","Oas1g", #IFNa
              "Ccl5", "Upp1", "Slamf7", "Cxcl9", "Gbp4","Cd74", #IFNg
              "Vav2","Tgfb1","Il10","Ccl24","Mmp8","Tmem176b","Trem2","Fn1") #protumor


apcs.liver<-SetIdent(apcs.liver, value = "RNA_Group")

pdf(paste0(ldir, "/Dotplot_stellare_APCs_FigS4L.pdf"), width=13, height=3)
PlotStellare(obs1 = apcs.liver,features1 = features1, valueG = "NewlablesM_12_clu", i="CD8 cDC1", group.by0="RNA_Group" , noCtrlvsAll=T, controGroup="SIINFEKL")
dev.off()

#####################################################################
############Figure S4M - RADAR PLOT MACROCLASSES####################
#####################################################################
apcs.liver@meta.data$Shortlables<-apcs.liver@meta.data$NewlablesM_12_clu
#DCs<-c("CD8 cDC1","moDCs", "Ccr7 DCs","pDCs","pre DCs")
#apcs.liver@meta.data$Shortlables[apcs.liver@meta.data$NewlablesM_12_clu%in%DCs]<- "DCs"
#granu<-c("Neutrophils","Basophils")
#apcs.liver@meta.data$Shortlables[apcs.liver@meta.data$NewlablesM_12_clu%in%granu]<- "Granulocytes"

plotRadar <- function(i){
  ploTData<- rbind(max1,min1,get(i))
  id <- sub(".db","",i)
  radarchart(ploTData, title = id, pcol=colors_border, pfcol=colors_in, plwd=2, plty=1, cglcol="grey", cglty = 1,cglwd=0.8)
}  #function to plot radarplot

##############LIVER RADARPLOT##########################
MHCI_genes <- list(c("H2-Q7", "H2-T22", "H2-Q4", "H2-K1", "H2-T23", "H2-M3", "H2-D1","Tap1","Tap2"))
MHCII_genes <- list( c("H2-Eb1", "H2-Ab1", "H2-Aa", "H2-DMb1", "H2-DMa", "Ciita"))
Protumoral_genes <- list(c("Vav2","Tgfb1","Il10","Ccl24","Mmp8","Tmem176b","Trem2","Fn1"))
IFNa_genes <- list(c("Ifi44", "Oasl1","Irf7","Isg15", "Isg20","Oas1a","Oas1g"))
IFNg_genes <-list(c("Ccl5", "Upp1", "Slamf7", "Cxcl9", "Gbp4","Cd74"))


apcs.liver <- AddModuleScore(apcs.liver, features = MHCI_genes, name = "MHCI_genes")
apcs.liver <- AddModuleScore(apcs.liver, features = MHCII_genes, name = "MHCII_genes")
apcs.liver <- AddModuleScore(apcs.liver, features = Protumoral_genes, name = "Protumoral_genes")
apcs.liver <- AddModuleScore(apcs.liver, features = IFNa_genes, name = "IFNa_genes")
apcs.liver <- AddModuleScore(apcs.liver, features = IFNg_genes, name = "IFNg_genes")

#Normalize data
#we needed to find a way to normalize the module scores. 
#we used a quantile normalization method.

M1<-apcs.liver@meta.data[,c("Shortlables", "RNA_Group", "MHCI_genes1","MHCII_genes1","Protumoral_genes1","IFNa_genes1","IFNg_genes1")]
M1[,3:7]<-limma::normalizeQuantiles(M1[,3:7])
Groups <-unique(apcs.liver$RNA_Group)
CellType<-unique(M1$Shortlables)

for (i in CellType){
  M2<-M1[M1$Shortlables%in%i,]
  M3a<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[1],3:7]),na.rm=T)
  M3b<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[2],3:7]),na.rm=T)
  M3c<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[3],3:7]),na.rm=T)
  M3d<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[4],3:7]),na.rm=T)
  M4<-rbind(M3a,M3b,M3c,M3d)
  rownames(M4)<-Groups
  colnames(M4)<-colnames(M2[,3:7])
  x<-as.data.frame(M4)
  assign(paste0(i,".db"),x)}

lsCells <- grep(".db",ls(),value=T)
MinMax<-lapply(lsCells,get)
max1 <- rep(do.call("max", MinMax),5)
min1 <- rep(do.call("min", MinMax),5)

colors_border=c(rgb(0,0,1,0.9), rgb(0,0.8,0,0.9), rgb(0,0.5,0.5,0.9), rgb(0,0,0,0.9))
colors_in=c(rgb(0,0,0.6,0.1), rgb(0,0.6,0,0.1), rgb(0,0.1,0.1,0.1), rgb(0.1,0.1,0.1,0.1))

pdf(paste0(pdir, "/Radar_plot_liverAPCs_shorterlables_FigS4M_new2.pdf"), width=17, height=6)
par(mfrow=c(2,5))
for (i in 1:length(unique(apcs.liver$Shortlables))){
  plotRadar(lsCells[i])
}
dev.off()

