library(Seurat)
library(openxlsx)
library(readxl)
library(tidyr)
library("RColorBrewer")
library(dplyr)
library(reshape2)
library(fgsea)
library(patchwork)
library(presto)
library(ggplot2)
library(matrixStats)
library(fmsb)

cluster_dir <- "/beegfs/scratch/ric.squadrito/ric.squadrito/90-856756828_scRNAseq_Notaro/Analysis_MM3/results2"

wdir <- paste0(cluster_dir, "/Result2_MNOT")
ldir <- paste0(cluster_dir, "/Liver_TandNK/")
pdir <- paste0(cluster_dir, "/Result2_MNOT/Plots")

#############################################################################
##########################LIVER MACS ANALYSIS################################
#############################################################################
obs1 <- readRDS(paste0(ldir, "Liver_TandNK_final.rds"))

#assign groups   
#name and order groups
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="li.OVA"] <- "liOVA"
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="li.OVA.Combo"] <- "OVA.Combo"
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="li.Stop"] <- "SIINFEKL"
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="li.Stop.Combo"] <- "SIINFEKL.Combo"

obs1@meta.data$RNA_Group <- factor(x = obs1@meta.data$RNA_Group, levels = c("SIINFEKL.Combo","SIINFEKL", "OVA.Combo","liOVA"))
obs1@meta.data$Tissue <- "Liver"


obs1@meta.data$NewlablesM<-as.numeric(obs1@meta.data$RNA_snn_h.orig.ident_res.3.2)
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(1)] <- "Naive CD4"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(8,2)] <- "Naive CD8"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(27)] <- "Th17 CD4"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(20)] <- "CD4 Treg"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(13)] <- "IFNg CD4"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(4)] <- "Il4 CD4"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(7)] <- "gd T"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(23)] <- "Act gd T"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(11)] <- "CD8 Teff2"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(0,3,10)] <- "CD8 Teff3"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(14,28)] <- "Early CD8"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(16)] <- "CD8 Teff1"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(5)] <- "CD8 prol"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(17)] <- "Cytotoxic NK"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(18,21,22,24,25)] <- "ILC-like"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(6,9,15)] <- "ILCs"
obs1@meta.data$NewlablesM[obs1@meta.data$RNA_snn_h.orig.ident_res.3.2%in%c(12)] <- "NK"

#create lables for all CD8 and cd4 t cells
obs1@meta.data$NewlablesG <- obs1@meta.data$NewlablesM
obs1@meta.data$NewlablesG[grep("CD4",obs1@meta.data$NewlablesM) ] <- "CD4 T cells"
obs1@meta.data$NewlablesG[grep("CD8",obs1@meta.data$NewlablesM)] <- "CD8 T cells"

#create lables CD4 and CD8 clusters wothout naive
obs1@meta.data$NewlablesS <- obs1@meta.data$NewlablesM
indCd4<- grepl("CD4",obs1@meta.data$NewlablesM) & !grepl("Naive",obs1@meta.data$NewlablesM)
indCd8<- grepl("CD8",obs1@meta.data$NewlablesM) & !grepl("Naive",obs1@meta.data$NewlablesM)
obs1@meta.data$NewlablesS[indCd4] <- "CD4 T cells"
obs1@meta.data$NewlablesS[indCd8] <- "CD8 T cells"
obs1@meta.data$NewlablesST <- paste0(obs1@meta.data$Tissue,".",obs1@meta.data$NewlablesS)


################################################
###Calculating hyperexpanded T cels#############
################################################
obs1$aa3.Tube <-  paste0(obs1$cdr3_aa2,".",obs1$RNA_Group)
obs1$aa3.Tube[is.na(obs1$cdr3_aa2)] <- NA
obs1@meta.data$ClonoFreq <- obs1@meta.data  %>% group_by(aa3.Tube)  %>% mutate(count = n()) %>% ungroup() %>%
  as.data.frame() %>% select (count)
obs1@meta.data$ClonoFreq[is.na(obs1$cdr3_aa2),] <- NA

obs1@meta.data$Clonetype  <- NA
obs1@meta.data$Clonetype[obs1@meta.data$ClonoFreq==1]  <- "unique"
obs1@meta.data$Clonetype[obs1@meta.data$ClonoFreq > 1 & obs1@meta.data$ClonoFreq <= 5]  <- "small"
obs1@meta.data$Clonetype[obs1@meta.data$ClonoFreq > 5 & obs1@meta.data$ClonoFreq <= 30]  <- "large"
obs1@meta.data$Clonetype[obs1@meta.data$ClonoFreq > 30]  <- "hyperexpanded"
obs1$Clonetype <- factor(x = obs1$Clonetype, levels = c("unique", "small", "large", "hyperexpanded"))#order clonotype variable

obs1@meta.data$Clonetype2 <- "Expand"
obs1@meta.data$Clonetype2[obs1@meta.data$ClonoFreq==1] <- "Other"
obs1@meta.data$Clonetype2[is.na(obs1@meta.data$ClonoFreq)] <- "Other"

obs1@meta.data$Clonetype2.Group <- paste0(obs1@meta.data$Clonetype2,".",obs1@meta.data$RNA_Group)
obs1@meta.data$Clonetype2.Group[obs1@meta.data$RNA_Group=="liOVA"] <- "liOVA"
obs1@meta.data$Clonetype2.Group[obs1@meta.data$RNA_Group=="SIINFEKL"] <- "SIINFEKL"
obs1@meta.data$Clonetype2.Group <- factor(x = obs1@meta.data$Clonetype2.Group, levels = c("liOVA", 
                                                                    "SIINFEKL", "Unique.OVA.Combo",
                                                        "Unique.SIINFEKL.Combo","Expand.OVA.Combo",
                                                        "Expand.SIINFEKL.Combo" ))#order clonotype variable

obs1@meta.data$Clonetype2.cells <- paste0(obs1@meta.data$Clonetype2,".",obs1@meta.data$NewlablesG)
obs1@meta.data$New_division2 <- "Other"
ind<- grepl("Expand.CD4 T cells",obs1@meta.data$Clonetype2.cells) 
obs1@meta.data$New_division2[ind] <- "Expanded CD4"
obs1@meta.data$New_division3<-paste0(obs1@meta.data$RNA_Group, ".",obs1@meta.data$New_division2)

obs1@meta.data$New_division3[obs1@meta.data$New_division3 =="liOVA.Expanded CD4"] <- "liOVA"
obs1@meta.data$New_division3[obs1@meta.data$New_division3 == "liOVA.Other"] <- "liOVA"
obs1@meta.data$New_division3[obs1@meta.data$New_division3 =="SIINFEKL.Expanded CD4"] <- "SIINFEKL"
obs1@meta.data$New_division3[obs1@meta.data$New_division3 =="SIINFEKL.Other"] <- "SIINFEKL"

unique(obs1@meta.data$New_division3)

############################################
######FINDING Tetramer reactive TCRs########
############################################
obs1@meta.data$TetramerT <- "Other"
obs1@meta.data$TetramerT[obs1@meta.data$ADT.Tetramer>315] <- "OVA.TCR"
df1 <- data.frame(obs1$cdr3_aa2, obs1$TetramerT,obs1$ClonoFreq,obs1$Tissue)
df1$aa3.OVA <-  paste0(obs1$cdr3_aa2,".",obs1$TetramerT)
df1 <- na.omit(df1)
df1l <- df1[df1$obs1.Tissue=="Liver",]
df2 <- df1l %>% group_by(aa3.OVA) %>% mutate(count = n()) %>% ungroup() %>% as.data.frame()
df3 <- df2 %>% select(obs1.cdr3_aa2,obs1.TetramerT,obs1.ClonoFreq,count) %>% unique() %>%
  pivot_wider(names_from = obs1.TetramerT, values_from = count) %>% as.data.frame()
df3[is.na(df3)] <- 0
OVA.TCRs <- df3$obs1.cdr3_aa2[df3[,4]/df3[,3]>1]
obs1$OVA.reactive <- ifelse(obs1$cdr3_aa2 %in% OVA.TCRs, "OVA", "Other")######Indicating Tetramer OVA in obs1
obs1@meta.data$Tetramer.CD8 <- ifelse(obs1$OVA.reactive == "OVA" & obs1$NewlablesG== "CD8 T cells", "OVA.TCR.CD8", "Other")


############DimPlot#######################

# Save UMAP plots

pdf(paste0(pdir, "/TAD12_TandNK_umap_FigS7I.pdf"), width=7, height=6) # Figure FigS7I
DimPlot(obs1, reduction = "umap.harmony.orig.ident",group.by = "NewlablesM", pt.size = 0.5, label = T, label.size = 3, repel = T)
dev.off() 
pdf(paste0(pdir, "/TAD12_tetramer_umap_FigS7J.pdf"), width=7, height=6) # Figure FigS7J
DimPlot(obs1, reduction = "umap.harmony.orig.ident",group.by = "OVA.reactive", pt.size = 0.5, label = F, order = c("OVA","Other"), cols = c("lightgrey","blue"))
dev.off()
pdf(paste0(pdir, "/TAD12_CD4_expanded_umap_FigS7K.pdf"), width=7, height=6) # Figure FigS7K
DimPlot(obs1, reduction = "umap.harmony.orig.ident", group.by = "New_division2", pt.size = 0.5, label = F, order = c("Expanded CD4","Other"), cols = c("lightgrey","blue"))
dev.off()

# Export DimPlot as excel
var_list <- c("UMAPh_1", "UMAPh_2","Tissue","orig.ident","Sample","RNA_Group","Tube","RNA_snn_h.orig.ident_res.1.2","NewlablesM","OVA.reactive","New_division2")
TandNK_df <- FetchData(obs1, vars = var_list)
TandNK_df$cell_ID <- rownames(TandNK_df)
write.xlsx(TandNK_df, file=paste0(pdir, "/TAD12_TandNK_umap_FigS7I_S7J_S7K.xlsx"), overwrite=T)


#############Dotplot stellare############
#load function
PlotStellare <- function(obs1=obs1,features1=features1,valueG="NewlablesG",
                         i="CD8 T cells",group.by0 ="Clonetype2.Group",controGroup="SIINFEKL",noCtrlvsAll=T){ 
  obs1<-SetIdent(obs1, value = valueG)
  pa1 <- DotPlot(obs1, features = features1,idents = i, dot.scale = 15,split.by = group.by0,
                 cols="RdBu")+RotatedAxis()
  df1 <- pa1$data
  contro0<- paste0(i,"_",controGroup)
  a1<- sub(paste0(i,"_"),"",unique(df1$id))
  
  dfcombo <- NULL
  for (ix in a1){if(ix!=controGroup){
    m.Combo <- FindMarkers(obs1, ident.1 = ix,ident.2=controGroup, group.by = group.by0,
                           subset.ident = i,features = features1,
                           min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
  }else{
    m.Combo <- FindMarkers(obs1, ident.1 = ix, group.by = group.by0,
                           subset.ident = i,features = features1,
                           min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
    if(noCtrlvsAll){m.Combo$p_val_adj <- 1}
  }
    m.Combo <- m.Combo[match(features1,rownames(m.Combo)),]
    m.Combo$ix <- ix
    dfcombo <- rbind(dfcombo,m.Combo)}
  
  df2 <- cbind(df1,dfcombo)
  data.frame(df2$id,df2$ix)
  df2$stars <-  ifelse(df2$p_val_adj< 0.001,"***",
                       ifelse(df2$p_val_adj< 0.01,"**",
                              ifelse(df2$p_val_adj< 0.05,"*","")))
  
  df2$id <- factor(x = df2$id, levels = paste0(i,"_",rev(a1)))
  
  a <- ggplot(df2, aes(y=id, x=features.plot, size=pct.exp ,color=avg.exp.scaled)) + 
    geom_point() +
    scale_size_area(max_size = 15) +
    scale_colour_gradient2(low= "blue",mid = "darkgrey",high="darkred") +    ####"#CCCCFF"
    labs(y='',x='')+
    geom_text(aes(label=stars,vjust=0.8),col="black",size = 4)+
    theme_classic()+
    theme(axis.text.y = element_text(color = "Black"))+
    theme(axis.text.x = element_text(angle = 45, hjust= 1, color = "Black"))+
    theme(axis.line.x=element_line(color="Black"))+
    theme(axis.line.y=element_line(color="Black"))+
    ggtitle(paste0(unique(obs1$Tissue),".",i," vs ",controGroup))
  return(a)}


featuresCD8<-c("Stat1","Ly6c2","Oas1a","Irf8","Ifitm3",   #IFNa genes
               "Il18rap","Il18r1","Ifngas1","Il12rb1","Gbp2", #IL12/IFNg genes
               "Tbx21","Klrg1","Cx3cr1","Tcf7","Klf2","Sell", #pex
               "Gzmb","Gzma","Prf1","Ifng","Tnf","Fasl",#effector
               "Pdcd1","Lag3","Ctla4","Havcr2","Tigit","Il10ra","Tox")#exhaustion

featuresCD4<-c("Ly6c2","Oas1a","Irf8","Ifitm3",#Ifna
               "Il18rap","Il18r1","Il12rb1","Gbp2", #Ifng genes 
               "Ifng","Tbx21","Gzmk","Stat1","Tnf","Cxcr3","Il2", #Th1/effector genes
               "Gata3","Il4","Il5","Lima1","Auh","Runx2","Smad2", #Th2               
               "Rorc","Il17a","Palld","Basp1","Tnfrsf8","Apoe") #Th17 
############
#Figure 4I
pdf(file=paste0(pdir, "/TAD12.tetramer.dotplot_Fig4I.pdf"), width=13, height=3)
PlotStellare(obs1, featuresCD8, "Tetramer.CD8","OVA.TCR.CD8","RNA_Group",controGroup="SIINFEKL",noCtrlvsAll=T)
dev.off()

# Figure 4J
pdf(file=paste0(pdir, "/TAD12.CD4T.featuresCD4_Fig4J.pdf"), width=13, height=3)
PlotStellare(obs1,featuresCD4,"NewlablesG","CD4 T cells","RNA_Group",controGroup="SIINFEKL",noCtrlvsAll=T)
dev.off()


# Create subsets for further analysis
tetramer.t<-subset(obs1, subset = TetramerT== "OVA.TCR" &
                     NewlablesG =="CD8 T cells")
CD8<-subset(obs1, subset =  NewlablesG =="CD8 T cells")
CD4<-subset(obs1, subset =  NewlablesG =="CD4 T cells")

######################################################
##########Figure 4M, Clonotye by group CD4###########
#####################################################
table(CD4$RNA_Group, CD4$Clonetype)



#####RADAR PLOTS############################################

###############################################################
############Figure S4H- RADADR PLOT OVA SPECIFIC##############
################################################################

Effector <- list(c("Gzmb","Gzma","Prf1","Ifng","Tnf","Fasl"))
Pex <-  list(c("Tbx21","Klrg1","Cx3cr1","Tcf7","Klf2","Sell"))
Exhaustion <- list(c("Pdcd1","Lag3","Ctla4","Havcr2","Tigit","Il10ra","Tox"))
IFNa_genes <- list(c("Stat1","Ly6c2","Oas1a","Irf8","Ifitm3") )
IFNg_genes <- list(c("Il18rap","Il18r1","Ifngas1","Il12rb1","Gbp2"))


tetramer.t <- AddModuleScore(tetramer.t, features = Effector, name = "Effector")
tetramer.t <- AddModuleScore(tetramer.t, features = Pex, name = "Pex")
tetramer.t <- AddModuleScore(tetramer.t, features = Exhaustion, name = "Exhaustion")
tetramer.t <- AddModuleScore(tetramer.t, features = IFNa_genes, name = "IFNa_genes")
tetramer.t <- AddModuleScore(tetramer.t, features = IFNg_genes, name = "IFNg_genes")


#Normalize data
#we needed to find a way to normalize the module scores. 
#we used a quantile normalization method.
#41 is "NewlablesM_clu"
#42 is "RNA_Group"
#45:49 are the module scores

M1<-tetramer.t@meta.data[,c("NewlablesM", "RNA_Group", "Effector1","Pex1","Exhaustion1","IFNa_genes1","IFNg_genes1")]
M1[,3:7]<-limma::normalizeQuantiles(M1[,3:7])
Groups <-unique(tetramer.t$RNA_Group)
CellType<-unique(M1$NewlablesM_clu)

#with Median
#TAMs
#Groups are OVA.IL12 OVA.IFNa OVA      Combo 
M2<-M1
M3a<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[1],3:7]),na.rm=T)
M3b<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[2],3:7]),na.rm=T)
M3c<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[3],3:7]),na.rm=T)
M3d<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[4],3:7]),na.rm=T)
M4<-rbind(M3a,M3b,M3c,M3d)
rownames(M4)<-Groups
colnames(M4)<-colnames(M2[,3:7])
x<-as.data.frame(M4)


max1 <- rep(do.call("max", x),5)
min1 <- rep(do.call("min", x),5)

ploTData<- rbind(max1,min1,x)
colors_border=c(rgb(0,0,1,0.9), rgb(0,0.8,0,0.9), rgb(0,0.5,0.5,0.9), rgb(0,0,0,0.9))
colors_in=c(rgb(0,0,0.6,0.1), rgb(0,0.6,0,0.1), rgb(0,0.1,0.1,0.1), rgb(0.1,0.1,0.1,0.1))

pdf(file=paste0(pdir, "/radar.plot.liver.tetramer_FigS4H.pdf"),width=5, height=5)
radarchart(ploTData, title = "OVA-reactive", pcol=colors_border, pfcol=colors_in, plwd=2, plty=1, cglcol="grey", cglty = 1,cglwd=0.8)
dev.off()


######################################################
##################Figure 4K- RADAR PLOT  CD4##########
######################################################

IFNa_genes<- list(c("Ly6c2","Oas1a","Irf8","Ifitm3") )
IFNg_genes<-list(c("Il18rap","Il18r1","Il12rb1","Gbp2"))
Th1<-list(c("Ifng","Tbx21","Gzmk","Stat1","Tnf","Cxcr3","Il2"))
Th2<-list(c("Gata3","Il4","Il5","Lima1","Auh","Runx2","Smad2"))
Th17<-list(c("Rorc","Il17a","Palld","Basp1","Tnfrsf8","Apoe"))


CD4 <- AddModuleScore(CD4, features = Th1, name = "Th1")
CD4 <- AddModuleScore(CD4, features = Th2, name = "Th2")
CD4 <- AddModuleScore(CD4, features = Th17, name = "Th17")
CD4 <- AddModuleScore(CD4, features = IFNa_genes, name = "IFNa_genes")
CD4 <- AddModuleScore(CD4, features = IFNg_genes, name = "IFNg_genes")


#Normalize data
#we needed to find a way to normalize the module scores. 
#we used a quantile normalization method.
#41 is "NewlablesM_clu"
#42 is "RNA_Group"
#45:49 are the module scores

names(CD4@meta.data)
M1<-CD4@meta.data[,c("NewlablesM", "RNA_Group", "Th11","Th21","Th171","IFNa_genes1","IFNg_genes1")]
M1[,3:7]<-limma::normalizeQuantiles(M1[,3:7])
Groups <-unique(CD4$RNA_Group)
CellType<-unique(M1$NewlablesM_clu)

#with Median
#TAMs
#Groups are OVA.IL12 OVA.IFNa OVA      Combo 
M2<-M1
M3a<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[1],3:7]),na.rm=T)
M3b<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[2],3:7]),na.rm=T)
M3c<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[3],3:7]),na.rm=T)
M3d<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[4],3:7]),na.rm=T)
M4<-rbind(M3a,M3b,M3c,M3d)
rownames(M4)<-Groups
colnames(M4)<-colnames(M2[,3:7])
x<-as.data.frame(M4)


max1 <- rep(do.call("max", x), 5)
min1 <- rep(do.call("min", x), 5)

ploTData<- rbind(max1,min1,x)
colors_border=c(rgb(0,0,1,0.9), rgb(0,0.8,0,0.9), rgb(0,0.5,0.5,0.9), rgb(0,0,0,0.9))
colors_in=c(rgb(0,0,0.6,0.1), rgb(0,0.6,0,0.1), rgb(0,0.1,0.1,0.1), rgb(0.1,0.1,0.1,0.1))

pdf(file=paste0(pdir, "/radar.plot.All.CD4T.cells2_Fig4K.pdf"), width=5, height=5)
radarchart(ploTData, title = "All CD4 T cells", pcol=colors_border, pfcol=colors_in, plwd=2, plty=1, cglcol="grey", cglty = 1,cglwd=0.8)
dev.off()


###########################################GSEA##########################################################
#miDB_sig4.MLS <- readRDS(paste0(username, "Dropbox (HSR Global)/90-756142658_RNAseq_Squadrito/05-DGE-Tumor/miDB_sig4.MLS.rds"))
miDB_sig4.MLS <- readRDS("/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/reference/miDB_sig4.MLS.rds")


############################################################
###############Figure 4L - GSEA CD4#########################
#############################################################

CD4<-SetIdent(CD4, value = "RNA_Group")

OVA.combo<-FindMarkers(CD4, ident.1="OVA.Combo",       ident.2="SIINFEKL", min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)
stop.combo<-FindMarkers(CD4, ident.1="SIINFEKL.Combo", ident.2="SIINFEKL", min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)

OVA.combo.ranks <- OVA.combo$avg_log2FC
stop.combo.ranks <- stop.combo$avg_log2FC

names(OVA.combo.ranks) <- rownames(OVA.combo)
names(stop.combo.ranks) <- rownames(stop.combo)


res.OVA.combo  <- fgsea(pathways=miDB_sig4.MLS, stats=OVA.combo.ranks,  minSize=0, maxSize=500, eps=0, nPermSimple=25000)
res.stop.combo <- fgsea(pathways=miDB_sig4.MLS, stats=stop.combo.ranks, minSize=0, maxSize=500, eps=0, nPermSimple=25000)

# Select columns of interest
res.OVA.combo2<-res.OVA.combo[,c(1,3,6,8)]
res.stop.combo2<-res.stop.combo[,c(1,3,6,8)]

# Merge in a single file and save xlsx
merge3 <- merge(x=res.OVA.combo2,y=res.stop.combo2,by="pathway", suffixes = c("-Combo", "-stopcombo"))

res.OVA.combo$origin<-"OVA.Combo"
res.stop.combo$origin<-"SIINFEKL.Combo"
merge.results<-rbind(res.OVA.combo,res.stop.combo)
#create variable with star for statistic
merge.results$stats <- ifelse(merge.results$padj < 0.0005, "***",
                              ifelse(merge.results$padj < 0.005, "**",
                                     ifelse(merge.results$padj < 0.05, "*", "")))


# Manually selected pathways
a1<-c("HALLMARK_INTERFERON_ALPHA_RESPONSE",
          "HALLMARK_INTERFERON_GAMMA_RESPONSE",
          "HALLMARK_IL2_STAT5_SIGNALING",
          "LPS_RO",
          "GOBP_INTERLEUKIN_18_PRODUCTION",
          "GOBP_INTERFERON_GAMMA_PRODUCTION",
          "GOBP_CELL_DIVISION",
          "HALLMARK_G2M_CHECKPOINT",
          "GOBP_NEGATIVE_REGULATION_OF_MACROPHAGE_ACTIVATION",
          "IL4_RO",
          "GOBP_RESPONSE_TO_INTERLEUKIN_17")

# Subset selected pathways
merge.results1 <-merge.results[merge.results$pathway %in% a1,]

# Rename pathways
merge.results1[merge.results1 == "HALLMARK_INTERFERON_ALPHA_RESPONSE"] <- "Response to IFNa"
merge.results1[merge.results1 == "HALLMARK_INTERFERON_GAMMA_RESPONSE"] <- "Response to IFNg"
merge.results1[merge.results1 == "HALLMARK_IL2_STAT5_SIGNALING"] <- "IL-2/STAT5 signalling"
merge.results1[merge.results1 == "LPS_RO"] <- "LPS signature (Cilenti et al)"
merge.results1[merge.results1 == "GOBP_INTERLEUKIN_18_PRODUCTION"] <- "IL-18 production"
merge.results1[merge.results1 == "GOBP_INTERFERON_GAMMA_PRODUCTION"] <- "Ifng production"
merge.results1[merge.results1 == "GOBP_CELL_DIVISION"] <- "Cell division"
merge.results1[merge.results1 == "HALLMARK_G2M_CHECKPOINT"] <- "Hallmark G2M checkpoint"
merge.results1[merge.results1 == "GOBP_NEGATIVE_REGULATION_OF_MACROPHAGE_ACTIVATION"] <- "Negative regulation of Macrophages activation"
merge.results1[merge.results1 == "IL4_RO"] <- "IL-4 Signature (Cilenti et al)"
merge.results1[merge.results1 == "GOBP_RESPONSE_TO_INTERLEUKIN_17"] <- "Response to IL-17"


# Order in the way we want to see
merge.results1$pathway<- factor(merge.results1$pathway, levels = rev(c("Response to IFNa",
                                                                   "Response to IFNg",
                                                                   "IL-2/STAT5 signalling",
                                                                   "LPS signature (Cilenti et al)",
                                                                   "IL-18 production",
                                                                   "Ifng production",
                                                                   "Cell division",
                                                                   "Hallmark G2M checkpoint",
                                                                   "Negative regulation of Macrophages activation",
                                                                   "IL-4 Signature (Cilenti et al)",
                                                                   "Response to IL-17")))

# Heatmap
y<-ggplot(merge.results1, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette="RdBu") +
  geom_text(aes(label = stats), vjust=0.75, angle=0, size=4) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color="Black"),
        axis.text.x = element_text(angle=45, hjust=1, color="Black"),
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black")) +
  ggtitle("GSEA CD4 vs SIINFEKL")
ggsave(filename = paste0(pdir, "/GSEA_CD4_T_cells_vs_SIINFEKL_Fig4L.pdf"), plot=y, width=5, height=3)
ggsave(filename = paste0(pdir, "/GSEA_CD4_T_cells_vs_SIINFEKL_Fig4L.png"), plot=y, width=5, height=3, dpi=200)

# a1_new_not_used<-c("GOBP_RESPONSE_TO_VIRUS",
#       "HALLMARK_INTERFERON_ALPHA_RESPONSE",
#       "GOBP_CHROMOSOME_SEGREGATION",
#       "HALLMARK_INTERFERON_GAMMA_RESPONSE",
#       "HALLMARK_IL2_STAT5_SIGNALING",
#       "LPS_RO",
#       "HALLMARK_G2M_CHECKPOINT",
#       "GOBP_CELL_DIVISION",
#       "Exhaustion_Wherry")

# Rename pathways
# merge.results1[merge.results1 == "GOBP_RESPONSE_TO_VIRUS"] <- "Response to virus"
# merge.results1[merge.results1 == "HALLMARK_INTERFERON_ALPHA_RESPONSE"] <- "Response to IFNa"
# merge.results1[merge.results1 == "HALLMARK_INTERFERON_GAMMA_RESPONSE"] <- "Response to IFNg"
# merge.results1[merge.results1 == "HALLMARK_IL2_STAT5_SIGNALING"] <- "IL-2/STAT5 signalling"
# merge.results1[merge.results1 == "LPS_RO"] <- "LPS signature (Cilenti et al)"
# merge.results1[merge.results1 == "HALLMARK_G2M_CHECKPOINT"] <- "G2M checkpoint"
# merge.results1[merge.results1 == "GOBP_CHROMOSOME_SEGREGATION"] <- "Chromosome segregation"
# merge.results1[merge.results1 == "GOBP_CELL_DIVISION"] <- "Cell division"
# merge.results1[merge.results1 == "Exhaustion_Wherry"] <- "Exhaustion signature (Wherry)"

# merge.results1$pathway<- factor(merge.results1$pathway, levels = rev(c("Response to virus",
#                                                                        "Response to IFNa",
#                                                                        "Response to IFNg", 
#                                                                        "IL-2/STAT5 signalling",
#                                                                        "LPS signature (Cilenti et al)",
#                                                                        "G2M checkpoint",
#                                                                        "Cell division",
#                                                                        "Chromosome segregation",
#                                                                        "Exhaustion signature (Wherry)")))

# Unbias heatmap
merge.results <- merge.results[order(merge.results$padj, decreasing = F)]
merge.results_temp <-merge.results[merge.results$padj < 0.05,]
filter_in <- head(unique(merge.results_temp$pathway), 100)
merge.results2 <-merge.results[merge.results$pathway %in% filter_in,]
merge.results2$origin<- factor(x = merge.results2$origin, levels = c("OVA.Combo","SIINFEKL.Combo"))

y<-ggplot(merge.results2, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette = "RdBu") +
  geom_text(aes(label = stats), vjust = 0.7,angle = 0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"), text = element_text(size = 15), 
        axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1, color = "Black"), 
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black"))
ggtitle("GSEA_CD4 vs SIINFEKL")
ggsave(filename = paste0(pdir, "/GSEA_CD4_T_cells_vs_SIINFEKL_unbias.pdf"), plot=y, width=15, height=30)


############################################################
###############Figure xxx-OLD - GSEA CD4#########################
#############################################################

CD4<-SetIdent(CD4, value = "RNA_Group")

OVA.combo<-FindMarkers(CD4, ident.1="OVA.Combo",       ident.2 ="liOVA", min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)
stop.combo<-FindMarkers(CD4, ident.1="SIINFEKL.Combo", ident.2= "liOVA", min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)
STOP<-FindMarkers(CD4, ident.1="SIINFEKL",             ident.2= "liOVA", min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)
liOVA<-FindMarkers(CD4, ident.1="liOVA",                                 min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)

OVA.combo.ranks <- OVA.combo$avg_log2FC
stop.combo.ranks <- stop.combo$avg_log2FC
STOP.ranks <- STOP$avg_log2FC
liOVA.ranks <- liOVA$avg_log2FC

names(OVA.combo.ranks) <- rownames(OVA.combo)
names(stop.combo.ranks) <- rownames(stop.combo)
names(STOP.ranks) <- rownames(STOP)
names(liOVA.ranks) <- rownames(liOVA)

res.OVA.combo  <- fgsea(pathways=miDB_sig4.MLS, stats=OVA.combo.ranks,  minSize=0, maxSize=500, eps=0, nPermSimple=25000)
res.stop.combo <- fgsea(pathways=miDB_sig4.MLS, stats=stop.combo.ranks, minSize=0, maxSize=500, eps=0, nPermSimple=25000)
res.STOP       <- fgsea(pathways=miDB_sig4.MLS, stats=STOP.ranks,       minSize=0, maxSize=500, eps=0, nPermSimple=25000)
res.liOVA      <- fgsea(pathways=miDB_sig4.MLS, stats=liOVA.ranks,      minSize=0, maxSize=500, eps=0, nPermSimple=25000)

# Select columns of interest
res.OVA.combo2<-res.OVA.combo[,c(1,3,6,8)]
res.stop.combo2<-res.stop.combo[,c(1,3,6,8)]
res.STOP2<-res.STOP[,c(1,3,6,8)]
res.liOVA2<-res.liOVA[,c(1,3,6,8)]

# Merge in a single file and save xlsx
merge1 <- merge(x=res.OVA.combo2,y=res.stop.combo2,by="pathway", suffixes = c("-Combo", "-stopcombo"))
merge2<-merge(x=res.STOP2,y=res.liOVA2,by="pathway", suffixes = c("-STOP", "-liOVA"))
merge3<-merge(merge1,merge2)

# setwd(pdir)
# write.xlsx(merge3,"GSEA_CD4_vsliOVA_OVA-vsall.xlsx",asTable = TRUE,rowNames=T) ####save file

# merge2<-merge1[merge1$`padj-Combo`<0.05,]
# merge3<-merge2[merge2$`padj-stopcombo`<0.05,]
# write.xlsx(merge3,"GSEA_CD4_vsSIINFEKL_only signifi.xlsx",asTable = TRUE,rowNames=T) ####save file


res.OVA.combo$origin<-"OVA.Combo"
res.stop.combo$origin<-"SIINFEKL.Combo"
res.STOP$origin<-"SIINFEKL"
res.liOVA$origin<-"li.OVA"
merge.results<-rbind(res.OVA.combo,res.stop.combo,res.STOP,res.liOVA)
#create variable with star for statistic
merge.results$stats <- ifelse(merge.results$padj < 0.0005, "***",
                              ifelse(merge.results$padj < 0.005, "**",
                                     ifelse(merge.results$padj < 0.05, "*", "")))


# Manually selected pathways
a1_OLD<-c("HALLMARK_INTERFERON_ALPHA_RESPONSE",
      "HALLMARK_INTERFERON_GAMMA_RESPONSE",
      "HALLMARK_IL2_STAT5_SIGNALING",
      "LPS_RO",
      "GOBP_INTERLEUKIN_18_PRODUCTION",
      "GOBP_INTERFERON_GAMMA_PRODUCTION",
      "GOBP_T_CELL_DIFFERENTIATION_INVOLVED_IN_IMMUNE_RESPONSE",
      "HALLMARK_E2F_TARGETS",
      "HALLMARK_G2M_CHECKPOINT",
      "GOBP_NEGATIVE_REGULATION_OF_MACROPHAGE_ACTIVATION",
      "IL4_RO",
      "GOBP_RESPONSE_TO_INTERLEUKIN_17")

a1<-c("GOBP_RESPONSE_TO_VIRUS",
      "HALLMARK_INTERFERON_ALPHA_RESPONSE",
      "GOCC_T_CELL_RECEPTOR_COMPLEX",
      "GOBP_PHAGOCYTOSIS",
      "HALLMARK_INTERFERON_GAMMA_RESPONSE",
      "HALLMARK_IL2_STAT5_SIGNALING",
      "LPS_RO",
      "GOBP_INTERFERON_GAMMA_PRODUCTION",
      "GOBP_T_CELL_DIFFERENTIATION_INVOLVED_IN_IMMUNE_RESPONSE",
      "Exhaustion_Wherry")

# Subset selected pathways
merge.results1 <-merge.results[merge.results$pathway %in% a1,]

# Rename pathways
merge.results1[merge.results1 == "GOBP_RESPONSE_TO_VIRUS"] <- "Response to virus"
merge.results1[merge.results1 == "HALLMARK_INTERFERON_ALPHA_RESPONSE"] <- "Response to IFNa"
merge.results1[merge.results1 == "HALLMARK_INTERFERON_GAMMA_RESPONSE"] <- "Response to IFNg"
merge.results1[merge.results1 == "HALLMARK_IL2_STAT5_SIGNALING"] <- "IL-2/STAT5 signalling"
merge.results1[merge.results1 == "LPS_RO"] <- "LPS signature (Cilenti et al)"
merge.results1[merge.results1 == "GOBP_INTERFERON_GAMMA_PRODUCTION"] <- "Ifng production"
merge.results1[merge.results1 == "GOCC_T_CELL_RECEPTOR_COMPLEX"] <- "T cell receptor complex"
merge.results1[merge.results1 == "GOBP_PHAGOCYTOSIS"] <- "Phagocytosis"
merge.results1[merge.results1 == "GOBP_T_CELL_DIFFERENTIATION_INVOLVED_IN_IMMUNE_RESPONSE"] <- "T cell differentiation"
merge.results1[merge.results1 == "Exhaustion_Wherry"] <- "Exhaustion signature (Wherry)"


# Order in the way we want to see
merge.results1$pathway<- factor(merge.results1$pathway, levels = rev(c("Response to virus",
                                                                       "Response to IFNa",
                                                                       "Response to IFNg", 
                                                                       "IL-2/STAT5 signalling",
                                                                       "LPS signature (Cilenti et al)",
                                                                       "Ifng production",
                                                                       "T cell differentiation",
                                                                       "T cell receptor complex",
                                                                       "Phagocytosis",
                                                                       "Exhaustion signature (Wherry)")))

# Heatmap
y<-ggplot(merge.results1, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette="RdBu") +
  geom_text(aes(label = stats), vjust=0.7, angle=0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color="Black"),
        axis.text.x = element_text(angle=45, hjust=1, color="Black"),
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black")) +
  ggtitle("GSEA CD4 vs liOVA")
ggsave(filename = paste0(pdir, "/GSEA_CD4_T_cells_vs_liOVA_Fig4.pdf"), plot=y, width=5, height=3)


# Unbias heatmap
merge.results <- merge.results[order(merge.results$padj, decreasing = F)]
merge.results_temp <-merge.results[merge.results$padj < 0.01,]
filter_in <- head(unique(merge.results_temp$pathway), 100)
merge.results2 <-merge.results[merge.results$pathway %in% filter_in,]
merge.results2$origin<- factor(x = merge.results2$origin, levels = c("li.OVA","SIINFEKL","OVA.Combo","SIINFEKL.Combo"))

y<-ggplot(merge.results2, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette = "RdBu") +
  geom_text(aes(label = stats), vjust = 0.7,angle = 0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"), text = element_text(size = 15), 
        axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1, color = "Black"), 
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black"))
ggtitle("GSEA_CD4 vs liOVA")
ggsave(filename = paste0(pdir, "/GSEA_CD4_T_cells_vs_liOVA_unbias.pdf"), plot=y, width=15, height=30)
