suppressPackageStartupMessages(library(Seurat))
suppressPackageStartupMessages(library(harmony))
suppressPackageStartupMessages(library(openxlsx))
suppressPackageStartupMessages(library(readxl))
suppressPackageStartupMessages(library(tidyr))
suppressPackageStartupMessages(library(ggplot2))
suppressPackageStartupMessages(library(RColorBrewer))   # Color palettes for visualization
suppressPackageStartupMessages(library(dplyr))


##############################################################################
################Figure S4D - Liver clusters dotplot markers###################

dataset <- "18"
Tissue <- "Liver" # "Liver" or "Tumor"

wd <- paste0("/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/Analysis_MM")
setwd(wd)

# Plot dir
plot_dir <- "/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/Analysis_MM/results3/Result3_MNOT/Plots"
dir.create(plot_dir, showWarnings = FALSE)

# Load the RDS
obs1 <- readRDS(paste0(wd, "/results2/", Tissue, "/", Tissue, "_final.rds"))

# Assign groups 

obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="liOVA_IL12"] <- "OVA.IL12"
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="liOVA_IFNa"]  <- "OVA.IFNa"
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="liOVA"]  <- "OVA"
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="Combo3x"]  <- "Combo"

#sample origin
obs1$Tube <- paste0(obs1$RNA_Group,obs1$hash.ID)
obs1@meta.data$RNA_Group<- factor(x = obs1@meta.data$RNA_Group, levels = c("OVA","OVA.IFNa","OVA.IL12","Combo"))

obs1@meta.data$Tissue <- obs1@meta.data$PROP.Source


# Liver
obs1 <- SetIdent(obs1, value = "Newlables2")
obs1@meta.data$Newlables2 <- factor(x = obs1@meta.data$Newlables2, levels = c("APCs","TandNK","B cells","Hepatocytes","Endothelial cells","Others"))

obs1_subset <- subset(obs1, Newlables2 != "Others")


# Dot Plot
features_to_plot_manual_liver_MNOT <- unique(c("Cd86", "Itgax", "Clec9a", "Flt3", "Clec4f", "Adgre1", "Lyz2", "Marco", "Cd14", # APCs
                                   "Cd3e", "Cd8a", "Cd4", "Nkg7", "Gzmb", "Cd3g", "Klrb1c", # TandNK
                                   "Cd79a", "Ms4a1", "Cd19", "Ighm", "Cd22", "Ebf1", "Pax5", # B cells
                                   "Alb", "Adh1", "Cyp3a11", "Serpina1a", "Apoa1", "Fgb", "Hamp", # Hepatocytes
                                   "Cdh5", "Pecam1", "Kdr", "Eng", "Nos3", "Esam", "Vwf" # Endothelial cells
))


paletteLength <- 100
myColor <- colorRampPalette(c("blue", "darkgrey", "darkred"))(paletteLength)


pdf(paste0(plot_dir, "/TAD018_", Tissue, "_dotplot.markers.Newlables2_FigS4D.pdf"), width=11, height=4)
dotplot1<-scCustomize::Clustered_DotPlot(obs1_subset,
                                         features = features_to_plot_manual_liver_MNOT,
                                         plot_km_elbow=F,
                                         row_label_size=10,
                                         flip=T, colors_use_exp = myColor,
                                         cluster_feature=F, cluster_ident=F)
dev.off()



##############################################################################
################Figure S4E - Tumor clusters dotplot markers###################


dataset <- "18"
Tissue <- "Tumor" # "Liver" or "Tumor"

wd <- paste0("/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A0", dataset, "/Analysis_MM")
setwd(wd)

# Plot dir
plot_dir <- "/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/Analysis_MM/results3/Result3_MNOT/Plots"
dir.create(plot_dir, showWarnings = FALSE)

# Load the RDS
obs1 <- readRDS(paste0(wd, "/results2/", Tissue, "/", Tissue, "_final.rds"))

# Assign groups 

obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="liOVA_IL12"] <- "OVA.IL12"
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="liOVA_IFNa"]  <- "OVA.IFNa"
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="liOVA"]  <- "OVA"
obs1@meta.data$RNA_Group[obs1@meta.data$PROP.Condition=="Combo3x"]  <- "Combo"

#sample origin
obs1$Tube <- paste0(obs1$RNA_Group,obs1$hash.ID)
obs1@meta.data$RNA_Group<- factor(x = obs1@meta.data$RNA_Group, levels = c("OVA","OVA.IFNa","OVA.IL12","Combo"))

obs1@meta.data$Tissue <- obs1@meta.data$PROP.Source

# Tumor
obs1 <- SetIdent(obs1, value = "Newlables2")
obs1@meta.data$Newlables2 <- factor(x = obs1@meta.data$Newlables2, levels = c("APCs","TandNK","B cells","Cancer cells","Others"))

obs1_subset <- subset(obs1, Newlables2 != "Others")



# Dot Plot
features_to_plot_manual_tumor_MNOT <- unique(c("Cd86", "Itgax", "Adgre1", "Lyz2", "Cd14", "Cd68", "Fcgr1", # APCs
                                               "Cd3e", "Cd8a", "Cd4", "Nkg7", "Gzmb", "Cd3g", # TandNK
                                               "Cd79a", "Ms4a1", "Cd19", "Ighm", "Cd22", "Ebf1", "Pax5", # B cells
                                               "Cd34", "Serpinf1", "Sparc", "Mxra7", "Fstl1" # Cancer cells
))

paletteLength <- 100
myColor <- colorRampPalette(c("blue", "darkgrey", "darkred"))(paletteLength)


pdf(paste0(plot_dir, "/TAD018_", Tissue, "_dotplot.markers.Newlables2_FigS4E.pdf"), width=10, height=3)
dotplot1<-scCustomize::Clustered_DotPlot(obs1_subset,
                                         features = features_to_plot_manual_tumor_MNOT,
                                         plot_km_elbow=F,
                                         row_label_size=10,
                                         flip=T, colors_use_exp = myColor,
                                         cluster_feature=F, cluster_ident=F)
dev.off()




