library(Seurat)
library(openxlsx)
library(readxl)
library(tidyr)
library("RColorBrewer")
library(dplyr)
library(reshape2)
library(fgsea)
library(patchwork)
library(presto)
library(matrixStats)
library(fmsb)
library(ggplot2)

cluster_dir <- "/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/Analysis_MM/results3"
wdir<- paste0(cluster_dir, "/Result3_MNOT")
tdir<- paste0(cluster_dir, "/Tumor_APCs/")
ldir<- paste0(cluster_dir, "/Liver_APCs/")
pdir<- paste0(cluster_dir, "/Result3_MNOT/Plots")

plotRadar <- function(i){
  ploTData<- rbind(max1,min1,get(i))
  id <- sub(".db","",i)
  radarchart(ploTData, title = id, pcol=colors_border, pfcol=colors_in, plwd=2, plty=1, cglcol="grey", cglty = 1, cglwd=0.8)
}  #function to plot radarplot

#############################################################################
##########################LIVER MACS#########################################
#############################################################################
apcs.liver <- readRDS(paste0(ldir, "/Liver_APCs_final.rds"))

# Assigning groups   
apcs.liver@meta.data$Tissue <- apcs.liver@meta.data$PROP.Source
apcs.liver@meta.data$RNA_Group <- apcs.liver@meta.data$PROP.Condition

apcs.liver@meta.data$RNA_Group[apcs.liver@meta.data$RNA_Group == "liOVA_IL12"] <- "OVA.Il12"
apcs.liver@meta.data$RNA_Group[apcs.liver@meta.data$RNA_Group == "liOVA_IFNa"] <- "OVA.Ifna"
apcs.liver@meta.data$RNA_Group[apcs.liver@meta.data$RNA_Group == "Combo3x"] <- "OVA.Combo"
apcs.liver@meta.data$RNA_Group <- factor(x = apcs.liver@meta.data$RNA_Group, levels = c("liOVA","OVA.Ifna","OVA.Il12","OVA.Combo"))

apcs.liver@meta.data$Tube <- paste0(apcs.liver@meta.data$hash.ID, apcs.liver@meta.data$RNA_Group)


########################################################################
#######################TUMOR###########################################
#########################################################################


# Load the RDS file
apcs.tumor <- readRDS(paste0(tdir, "Tumor_APCs_final.rds"))


# Assigning tissue, origin, and ordering
apcs.tumor@meta.data$Tissue <- apcs.tumor@meta.data$PROP.Source
apcs.tumor@meta.data$RNA_Group <- apcs.tumor@meta.data$PROP.Condition

apcs.tumor@meta.data$RNA_Group[apcs.tumor@meta.data$RNA_Group == "liOVA_IL12"] <- "OVA.Il12"
apcs.tumor@meta.data$RNA_Group[apcs.tumor@meta.data$RNA_Group == "liOVA_IFNa"] <- "OVA.Ifna"
apcs.tumor@meta.data$RNA_Group[apcs.tumor@meta.data$RNA_Group == "Combo3x"] <- "OVA.Combo"
apcs.tumor@meta.data$RNA_Group <- factor(x = apcs.tumor@meta.data$RNA_Group, levels = c("liOVA","OVA.Ifna","OVA.Il12","OVA.Combo"))

apcs.tumor@meta.data$Tube <- paste0(apcs.tumor@meta.data$hash.ID, apcs.tumor@meta.data$RNA_Group)


# Refining labels
apcs.tumor$NewlablesM_clu[apcs.tumor$NewlablesM_clu == "pre DCs2"] <- "Macrophages"


############DimPlots

pdf(paste0(pdir, "/Liver_umapAPC_Fig2C.pdf"), width = 8, height = 6)
DimPlot(apcs.liver, reduction = "umap.harmony.orig.ident", group.by = "NewlablesM_clu", label = T, label.size = 6, repel = T)
dev.off()

# Export DimPlot as excel
var_list <- c("UMAPh_1", "UMAPh_2","Tissue","orig.ident","Sample","RNA_Group","Tube","RNA_snn_h.orig.ident_res.1.2","NewlablesM_clu")
apcs.liver_df <- FetchData(apcs.liver, vars = var_list)
apcs.liver_df$cell_ID <- rownames(apcs.liver_df)
write.xlsx(apcs.liver_df, file=paste0(pdir, "/Liver_umapAPC_Fig2C.xlsx"), overwrite=T)

pdf(paste0(pdir, "/Tumor_umapAPC_Fig2D.pdf"), width = 8, height = 6)
DimPlot(apcs.tumor, reduction = "umap.harmony.orig.ident", group.by = "NewlablesM_clu", label = T, label.size = 6, repel = T)
dev.off()

var_list <- c("UMAPh_1", "UMAPh_2","Tissue","orig.ident","Sample","RNA_Group","Tube","RNA_snn_h.orig.ident_res.1.2","NewlablesM_clu")
apcs.tumor_df <- FetchData(apcs.tumor, vars = var_list)
apcs.tumor_df$cell_ID <- rownames(apcs.tumor_df)
write.xlsx(apcs.tumor_df, file=paste0(pdir, "/Tumor_umapAPC_Fig2D.xlsx"), overwrite=T)

# All Liver
ALL_liver <- readRDS("/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/Analysis_MM/results2/Liver/Liver_final.rds")

ALL_liver@meta.data$Tissue <- ALL_liver@meta.data$PROP.Source
ALL_liver@meta.data$RNA_Group <- ALL_liver@meta.data$PROP.Condition
ALL_liver@meta.data$RNA_Group[ALL_liver@meta.data$RNA_Group == "liOVA_IL12"] <- "OVA.Il12"
ALL_liver@meta.data$RNA_Group[ALL_liver@meta.data$RNA_Group == "liOVA_IFNa"] <- "OVA.Ifna"
ALL_liver@meta.data$RNA_Group[ALL_liver@meta.data$RNA_Group == "Combo3x"] <- "OVA.Combo"
ALL_liver@meta.data$RNA_Group <- factor(x = ALL_liver@meta.data$RNA_Group, levels = c("liOVA","OVA.Ifna","OVA.Il12","OVA.Combo"))
ALL_liver@meta.data$Tube <- paste0(ALL_liver@meta.data$hash.ID, ALL_liver@meta.data$RNA_Group)

pdf(paste0(pdir, "/Liver_umap_Fig2A.pdf"), width = 8, height = 6)
DimPlot(ALL_liver, reduction = "umap.harmony.orig.ident", group.by = "Newlables2", label = T, label.size = 6, repel = T)
dev.off()

var_list <- c("UMAPh_1", "UMAPh_2","Tissue","orig.ident","Sample","RNA_Group","Tube","RNA_snn_h.orig.ident_res.0.6","Newlables2")
ALL_liver_df <- FetchData(ALL_liver, vars = var_list)
ALL_liver_df$cell_ID <- rownames(ALL_liver_df)
write.xlsx(ALL_liver_df, file=paste0(pdir, "/Liver_umap_Fig2A_FigS4B.xlsx"), overwrite=T)

# All Tumor
ALL_tumor <- readRDS("/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/Analysis_MM/results2/Tumor/Tumor_final.rds")

ALL_tumor@meta.data$Tissue <- ALL_tumor@meta.data$PROP.Source
ALL_tumor@meta.data$RNA_Group <- ALL_tumor@meta.data$PROP.Condition
ALL_tumor@meta.data$RNA_Group[ALL_tumor@meta.data$RNA_Group == "liOVA_IL12"] <- "OVA.Il12"
ALL_tumor@meta.data$RNA_Group[ALL_tumor@meta.data$RNA_Group == "liOVA_IFNa"] <- "OVA.Ifna"
ALL_tumor@meta.data$RNA_Group[ALL_tumor@meta.data$RNA_Group == "Combo3x"] <- "OVA.Combo"
ALL_tumor@meta.data$RNA_Group <- factor(x = ALL_tumor@meta.data$RNA_Group, levels = c("liOVA","OVA.Ifna","OVA.Il12","OVA.Combo"))
ALL_tumor@meta.data$Tube <- paste0(ALL_tumor@meta.data$hash.ID, ALL_tumor@meta.data$RNA_Group)

pdf(paste0(pdir, "/Tumor_umap_Fig2B.pdf"), width = 8, height = 6)
DimPlot(ALL_tumor, reduction = "umap.harmony.orig.ident", group.by = "Newlables2", label = T, label.size = 6, repel = T)
dev.off()

var_list <- c("UMAPh_1", "UMAPh_2","Tissue","orig.ident","Sample","RNA_Group","Tube","RNA_snn_h.orig.ident_res.0.6","Newlables2")
ALL_tumor_df <- FetchData(ALL_tumor, vars = var_list)
ALL_tumor_df$cell_ID <- rownames(ALL_tumor_df)
write.xlsx(ALL_tumor_df, file=paste0(pdir, "/Tumor_umap_Fig2B_FigS4C.xlsx"), overwrite=T)

# Macrophages Tumor
macrophages_tumor <- readRDS("/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/Analysis_MM/results3/macrophages_tumor/macrophages_tumor_final.rds")

macrophages_tumor@meta.data$Tissue <- macrophages_tumor@meta.data$PROP.Source
macrophages_tumor@meta.data$RNA_Group <- macrophages_tumor@meta.data$PROP.Condition
macrophages_tumor@meta.data$RNA_Group[macrophages_tumor@meta.data$RNA_Group == "liOVA_IL12"] <- "OVA.Il12"
macrophages_tumor@meta.data$RNA_Group[macrophages_tumor@meta.data$RNA_Group == "liOVA_IFNa"] <- "OVA.Ifna"
macrophages_tumor@meta.data$RNA_Group[macrophages_tumor@meta.data$RNA_Group == "Combo3x"] <- "OVA.Combo"
macrophages_tumor@meta.data$RNA_Group <- factor(x = macrophages_tumor@meta.data$RNA_Group, levels = c("liOVA","OVA.Ifna","OVA.Il12","OVA.Combo"))
macrophages_tumor@meta.data$Tube <- paste0(macrophages_tumor@meta.data$hash.ID, macrophages_tumor@meta.data$RNA_Group)

pdf(paste0(pdir, "/macrophages_tumor_umap_res.0.3_FigS5C.pdf"), width = 8, height = 6)
DimPlot(macrophages_tumor, reduction = "umap.harmony.orig.ident", group.by = "RNA_snn_h.orig.ident_res.0.3", label = T, label.size = 6, repel = T)
dev.off()

var_list <- c("UMAPh_1", "UMAPh_2","Tissue","orig.ident","Sample","RNA_Group","Tube","RNA_snn_h.orig.ident_res.0.3")
macrophages_tumor_df <- FetchData(macrophages_tumor, vars = var_list)
macrophages_tumor_df$cell_ID <- rownames(macrophages_tumor_df)
write.xlsx(macrophages_tumor_df, file=paste0(pdir, "/macrophages_tumor_umap_res.0.3_FigS5C.xlsx"), overwrite=T)

##############DOTPLOT STELLARI#####################################
# Selected genes for dotplot
features1 = c("H2-Q7", "H2-T22", "H2-Q4", "H2-K1", "H2-T23", "H2-M3", "H2-D1","Tap1","Tap2", #MHCI
              "H2-Eb1", "H2-Ab1", "H2-Aa", "H2-DMb1", "H2-DMa", "Ciita", #MHCII
              "Ifi44", "Oasl1","Irf7","Isg15", "Isg20","Oas1a","Oas1g", #IFNa
              "Ccl5", "Upp1", "Slamf7", "Cxcl9", "Gbp4","Cd74", #IFNg
              "Vav2","Tgfb1","Il10","Ccl24","Mmp8","Tmem176b","Trem2","Fn1") #protumor

###########Figure 2E############
###############################
apcs.liver<-SetIdent(apcs.liver, value = "Tissue")

pa1 <- DotPlot(apcs.liver, features = features1,idents = "Liver", dot.scale = 15, split.by = "RNA_Group",
               cols="RdBu") + RotatedAxis()
i<-"Liver" # Is subset.ident = i necessary?
df1 <- pa1$data
df1$id <-  factor(x = df1$id, levels = unique(df1$id)[c(4,1,2,3)])

m.Combo <- FindMarkers(apcs.liver, ident.1 = "OVA.Combo", ident.2 = "liOVA", group.by = "RNA_Group",
                       subset.ident = i, features = features1,
                       min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
m.Combo <- m.Combo[match(features1, rownames(m.Combo)),]
m.IL12 <- FindMarkers(apcs.liver, ident.1 = "OVA.Il12", ident.2 = "liOVA", group.by = "RNA_Group",
                      subset.ident = i,features = features1,
                      min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
m.IL12 <- m.IL12[match(features1,rownames(m.IL12)),]
m.IFNa <- FindMarkers(apcs.liver, ident.1 = "OVA.Ifna", ident.2 = "liOVA", group.by = "RNA_Group",
                      subset.ident = i, features = features1,
                      min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
m.IFNa <- m.IFNa[match(features1,rownames(m.IFNa)),]
m.OVA <- FindMarkers(apcs.liver, ident.1 = "liOVA", group.by = "RNA_Group",
                     subset.ident = i, features = features1,
                     min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
m.OVA <- m.OVA[match(features1,rownames(m.OVA)),]
m.OVA$p_val_adj<-1
markers1 <- rbind(m.IL12,m.IFNa,m.OVA,m.Combo)
df2 <- cbind(df1,markers1)
df2$stars <-  ifelse(df2$p_val_adj< 0.001,"***",
                     ifelse(df2$p_val_adj< 0.01,"**",
                            ifelse(df2$p_val_adj< 0.05,"*","")))

a<-ggplot(df2, aes(x=features.plot, y=id, size=pct.exp ,color=avg.exp.scaled)) + 
  geom_point() +
  scale_size_area(max_size = 10) +
  scale_colour_gradient2(low= "blue",mid = "darkgrey",high="darkred") +    ####"#CCCCFF"
  labs(y='',x='')+
  geom_text(aes(label=stars,vjust=0.8),col="black",size = 4)+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"))+
  theme(axis.text.x = element_text(angle = 45, hjust= 1, color = "Black"))+
  theme(axis.line.x=element_line(color="Black"))+
  theme(axis.line.y=element_line(color="Black"))+
  ggtitle("Dotplot liver APCs")
ggsave(filename = paste0(pdir, "/Dotplot_stellare_liverAPCs_Fig2E.pdf"), plot=1, width=11, height=3)

#############TUMOR#################################
#####################Figure 2F####################

apcs.tumor<-SetIdent(apcs.tumor, value = "Tissue")
pa1 <- DotPlot(apcs.tumor, features = features1,idents = "Tumor", dot.scale = 15, split.by = "RNA_Group",
               cols="RdBu") + RotatedAxis()

i<-"Tumor"
df1 <- pa1$data
df1$id <-  factor(x = df1$id, levels = unique(df1$id)[c(4,1,2,3)])

m.Combo <- FindMarkers(apcs.tumor, ident.1 = "OVA.Combo",ident.2 = "liOVA", group.by = "RNA_Group",
                       subset.ident = i,features = features1,
                       min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
m.Combo <- m.Combo[match(features1,rownames(m.Combo)),]
m.IL12 <- FindMarkers(apcs.tumor, ident.1 = "OVA.Il12",ident.2 = "liOVA", group.by = "RNA_Group",
                      subset.ident = i,features = features1,
                      min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
m.IL12 <- m.IL12[match(features1,rownames(m.IL12)),]
m.IFNa <- FindMarkers(apcs.tumor, ident.1 = "OVA.Ifna",ident.2 = "liOVA", group.by = "RNA_Group",
                      subset.ident = i,features = features1,
                      min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
m.IFNa <- m.IFNa[match(features1,rownames(m.IFNa)),]
m.OVA <- FindMarkers(apcs.tumor, ident.1 = "liOVA", group.by = "RNA_Group",
                     subset.ident = i,features = features1,
                     min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
m.OVA <- m.OVA[match(features1,rownames(m.OVA)),]
m.OVA$p_val_adj<-1
markers1 <- rbind(m.IL12,m.IFNa,m.OVA,m.Combo)
df2 <- cbind(df1,markers1)
df2$stars <-  ifelse(df2$p_val_adj< 0.001,"***",
                     ifelse(df2$p_val_adj< 0.01,"**",
                            ifelse(df2$p_val_adj< 0.05,"*","")))

a<-ggplot(df2, aes(x=features.plot, y=id, size=pct.exp ,color=avg.exp.scaled)) + 
  geom_point() +
  scale_size_area(max_size = 10) +
  scale_colour_gradient2(low= "blue",mid = "darkgrey",high="darkred") +    ####"#CCCCFF"
  labs(y='',x='')+
  geom_text(aes(label=stars,vjust=0.8),col="black",size = 4)+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"))+
  theme(axis.text.x = element_text(angle = 45, hjust= 1, color = "Black"))+
  theme(axis.line.x=element_line(color="Black"))+
  theme(axis.line.y=element_line(color="Black"))+
  ggtitle("Dotplot tumor APCs")
ggsave(filename = paste0(pdir, "/Dotplot_stellare_tumorAPCs_Fig2F.pdf"), plot=1, width=11, height=3)

###############RADAR PLOT WITH MACROCLASS LIVER AND TUMOR#################################
###############Figure 2G#################################################################

####Create a new label to cluster DCs and Granulocytes together
apcs.liver@meta.data$Shortlables <- apcs.liver@meta.data$NewlablesM_clu
apcs.tumor@meta.data$Shortlables <- apcs.tumor@meta.data$NewlablesM_clu

DCs<-c("CD8 cDC1", "moDCs", "Ccr7 DCs", "pDCs", "pre DCs")
apcs.liver@meta.data$Shortlables[apcs.liver@meta.data$NewlablesM_clu%in%DCs] <- "DCs"
apcs.tumor@meta.data$Shortlables[apcs.tumor@meta.data$NewlablesM_clu%in%DCs] <- "DCs"

granu<-c("Neutrophils", "Basophils")
apcs.liver@meta.data$Shortlables[apcs.liver@meta.data$NewlablesM_clu%in%granu] <- "Granulocytes"
apcs.tumor@meta.data$Shortlables[apcs.tumor@meta.data$NewlablesM_clu%in%granu] <- "Granulocytes"

table(apcs.liver@meta.data$NewlablesM_clu)
table(apcs.tumor@meta.data$NewlablesM_clu)

##############LIVER RADARPLOT##########################
MHCI_genes <- list(c("H2-Q7", "H2-T22", "H2-Q4", "H2-K1", "H2-T23", "H2-M3", "H2-D1","Tap1","Tap2"))
MHCII_genes <- list( c("H2-Eb1", "H2-Ab1", "H2-Aa", "H2-DMb1", "H2-DMa", "Ciita"))
Protumoral_genes <- list(c("Vav2","Tgfb1","Il10","Ccl24","Mmp8","Tmem176b","Trem2","Fn1") )
IFNa_genes <- list(c("Ifi44", "Oasl1","Irf7","Isg15", "Isg20","Oas1a","Oas1g") )
IFNg_genes <-list(c("Ccl5", "Upp1", "Slamf7", "Cxcl9", "Gbp4","Cd74"))

apcs.liver <- AddModuleScore(apcs.liver, features = MHCI_genes, name = "MHCI_genes")
apcs.liver <- AddModuleScore(apcs.liver, features = MHCII_genes, name = "MHCII_genes")
apcs.liver <- AddModuleScore(apcs.liver, features = Protumoral_genes, name = "Protumoral_genes")
apcs.liver <- AddModuleScore(apcs.liver, features = IFNa_genes, name = "IFNa_genes")
apcs.liver <- AddModuleScore(apcs.liver, features = IFNg_genes, name = "IFNg_genes")

names(apcs.liver@meta.data)
#Normalize data
#we needed to find a way to normalize the module scores. 
#we used a quantile normalization method.
#41 is "Shortlables"
#42 is "RNA_Group"
#45:49 are the module scores

M1<-apcs.liver@meta.data[,c("NewlablesM_clu", "RNA_Group", "MHCI_genes1","MHCII_genes1","Protumoral_genes1","IFNa_genes1","IFNg_genes1")]
#M1<-apcs.liver@meta.data[,c(45, 42, 46:50)]
M1[,3:7]<-limma::normalizeQuantiles(M1[,3:7])
Groups <-unique(apcs.liver$RNA_Group)
CellType<-unique(M1$NewlablesM_clu)

for (i in CellType){
  M2<-M1[M1$NewlablesM_clu%in%i,]
  M3a<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[1],3:7]),na.rm=T)
  M3b<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[2],3:7]),na.rm=T)
  M3c<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[3],3:7]),na.rm=T)
  M3d<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[4],3:7]),na.rm=T)
  M4<-rbind(M3a,M3b,M3c,M3d)
  rownames(M4)<-Groups
  colnames(M4)<-colnames(M2[,3:7])
  x<-as.data.frame(M4)
  assign(paste0(i,".db"),x)}

lsCells <- grep(".db",ls(),value=T)
MinMax<-lapply(lsCells,get)
max1 <- rep(do.call("max", MinMax),5)
min1 <- rep(do.call("min", MinMax),5)

colors_border=c(rgb(0,0,0,0.9), rgb(0.1,0.6,0.2,0.9), rgb(0.8,0.1,0.1,0.9), rgb(0.1,0.2,1,0.9))
colors_in=c(rgb(0,0,0,0.1), rgb(0.1,0.6,0.2,0.1), rgb(0.8,0.1,0.1,0.1), rgb(0.1,0.2,1,0.1))

pdf(paste0(pdir, "/Radar_plot_liverAPCs_NewlablesM_clu_Fig.2G_part1.pdf"), width=18, height=6)
par(mfrow=c(2,5))
for (i in 1:length(unique(apcs.liver$NewlablesM_clu))){
  plotRadar(lsCells[i])
}
dev.off()

################TUMOR RADARPLOT#####################
rm(list = grep(".db", ls(), value = TRUE))
MHCI_genes <- list(c("H2-Q7", "H2-T22", "H2-Q4", "H2-K1", "H2-T23", "H2-M3", "H2-D1","Tap1","Tap2"))
MHCII_genes <- list( c("H2-Eb1", "H2-Ab1", "H2-Aa", "H2-DMb1", "H2-DMa", "Ciita"))
Protumoral_genes <- list(c("Vav2","Tgfb1","Il10","Ccl24","Mmp8","Tmem176b","Trem2","Fn1") )
IFNa_genes <- list(c("Ifi44", "Oasl1","Irf7","Isg15", "Isg20","Oas1a","Oas1g") )
IFNg_genes <- list(c("Ccl5", "Upp1", "Slamf7", "Cxcl9", "Gbp4","Cd74"))

apcs.tumor <- AddModuleScore(apcs.tumor, features = MHCI_genes, name = "MHCI_genes")
apcs.tumor <- AddModuleScore(apcs.tumor, features = MHCII_genes, name = "MHCII_genes")
apcs.tumor <- AddModuleScore(apcs.tumor, features = Protumoral_genes, name = "Protumoral_genes")
apcs.tumor <- AddModuleScore(apcs.tumor, features = IFNa_genes, name = "IFNa_genes")
apcs.tumor <- AddModuleScore(apcs.tumor, features = IFNg_genes, name = "IFNg_genes")

M1<-apcs.tumor@meta.data[,c("NewlablesM_clu", "RNA_Group", "MHCI_genes1","MHCII_genes1","Protumoral_genes1","IFNa_genes1","IFNg_genes1")]
#M1<-apcs.tumor@meta.data[,c(46, 43, 47:51)]
M1[,3:7]<-limma::normalizeQuantiles(M1[,3:7])
Groups <-unique(apcs.tumor$RNA_Group)
CellType<-unique(M1$NewlablesM_clu)

for (i in CellType){
  M2<-M1[M1$NewlablesM_clu%in%i,]
  M3a<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[1],3:7]),na.rm=T)
  M3b<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[2],3:7]),na.rm=T)
  M3c<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[3],3:7]),na.rm=T)
  M3d<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[4],3:7]),na.rm=T)
  M4<-rbind(M3a,M3b,M3c,M3d)
  rownames(M4)<-Groups
  colnames(M4)<-colnames(M2[,3:7])
  x<-as.data.frame(M4)
  assign(paste0(i,".db"),x)}

lsCells <- grep(".db",ls(),value=T)
MinMax<-lapply(lsCells,get)
max1 <- rep(do.call("max", MinMax),5)
min1 <- rep(do.call("min", MinMax),5)

colors_border=c(rgb(0,0,0,0.9), rgb(0.1,0.6,0.2,0.9), rgb(0.8,0.1,0.1,0.9), rgb(0.1,0.2,1,0.9))
colors_in=c(rgb(0,0,0,0.1), rgb(0.1,0.6,0.2,0.1), rgb(0.8,0.1,0.1,0.1), rgb(0.1,0.2,1,0.1))

pdf(paste0(pdir, "/Radar_plot_tumorAPCs_NewlablesM_clu_Fig.2G_part2.pdf"), width=18, height=6)
par(mfrow=c(2,5))
for (i in 1:length(unique(apcs.tumor$NewlablesM_clu))){
  plotRadar(lsCells[i])
}
dev.off()


#############GSEA###################
########Create a single file with all the NES and Pvalue_adj, PLOT HEATMAP###############################
################################Only liver macs##########################################################
#miDB_sig4.MLS <- readRDS("C:/Users/notaro.marco/Dropbox (HSR Global)/90-756142658_RNAseq_Squadrito/05-DGE-Tumor/miDB_sig4.MLS.rds")
miDB_sig4.MLS <- readRDS("/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/reference/miDB_sig4.MLS.rds")

#################Figure S2C Liver#######################################

macrophage.L<-subset(apcs.liver, subset = NewlablesM_clu== "Monocytes" |
                       NewlablesM_clu== "Macrophages" |
                       NewlablesM_clu== "KCs")

macrophage.L<-SetIdent(macrophage.L, value = "RNA_Group")

# Here there is some discussions about what parameters to use to rank genes for fgsea: https://github.com/ctlab/fgsea/issues/50

combo<-FindMarkers(macrophage.L, ident.1="OVA.Combo",ident.2 ="liOVA", min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1) # used min.pct = -Inf or 0.01
IL12<-FindMarkers(macrophage.L, ident.1="OVA.Il12",ident.2 ="liOVA", min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
IFNa<-FindMarkers(macrophage.L, ident.1="OVA.Ifna",ident.2 ="liOVA", min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
OVA<-FindMarkers(macrophage.L, ident.1="liOVA",                      min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)

combo.ranks <- combo$avg_log2FC
IL12.ranks <- IL12$avg_log2FC
IFNa.ranks <- IFNa$avg_log2FC
OVA.ranks <- OVA$avg_log2FC

names(combo.ranks) <- rownames(combo)
names(IL12.ranks) <- rownames(IL12)
names(IFNa.ranks) <- rownames(IFNa)
names(OVA.ranks) <- rownames(OVA)

#summary(combo.ranks)
#n_occur <- data.frame(table(combo.ranks))

res.combo<-fgsea(pathways = miDB_sig4.MLS, stats = combo.ranks, minSize=0, maxSize=500, eps=0) # I added eps=0
res.IL12<-fgsea(pathways = miDB_sig4.MLS, stats = IL12.ranks, minSize=0, maxSize=500, eps=0)
res.IFNa<-fgsea(pathways = miDB_sig4.MLS, stats = IFNa.ranks, minSize=0, maxSize=500, eps=0)
res.OVA<-fgsea(pathways = miDB_sig4.MLS, stats = OVA.ranks, minSize=0, maxSize=500, eps=0) # nPermSimple=500000 long calculation, saved RDS, needed because it cant calculate pval for some pathways due to high variability
#saveRDS(res.OVA, paste0(pdir, "FGSEA_KCmonoMacs_liver_OVAvsAll_nperm500000.rds"))

# Select the columns of interest
res.combo2<-res.combo[,c(1,3,6,8)]
res.IL122<-res.IL12[,c(1,3,6,8)]
res.IFNa2<-res.IFNa[,c(1,3,6,8)]
res.OVA2<-res.OVA[,c(1,3,6,8)]

# Merge in a single file and save as xlsx
merge1 <- merge(x=res.combo2,y=res.IL122,by="pathway", suffixes = c("-Combo", "-Il12"))
merge2 <- merge(x=res.IFNa2,y=res.OVA2,by="pathway", suffixes = c("-IFna", "-OVA"))
merge3<-merge(x=merge1,y=merge2,by="pathway")
write.xlsx(merge3, paste0(pdir, "/GSEA_L_monomackc_vsOVA_min.pct0.01.xlsx"), asTable=T, rowNames=T)


#################GSEA Heatmap of selected###################################
# Rearrange data to plot heatmap
res.combo$origin<-"OVA.Combo"
res.IL12$origin<-"OVA.Il12"
res.IFNa$origin<-"OVA.IFNa"
res.OVA$origin<-"liOVA"

merge.results<-rbind(res.combo,res.IL12,res.IFNa,res.OVA)

# Create a variable with star for statistic
merge.results$stats <- ifelse(merge.results$padj < 0.0005, "***",
                              ifelse(merge.results$padj < 0.005, "**",
                                     ifelse(merge.results$padj < 0.05, "*", "")))

#merge.results$origin <- factor(x = merge.results$origin, levels = c("liOVA","OVA.IFNa","OVA.Il12","OVA.Combo"))

# Manually selected pathways
a1<-c("IFNa_RO",
"HALLMARK_INTERFERON_GAMMA_RESPONSE",
"GOMF_ANTIGEN_BINDING",
"GOBP_POSITIVE_REGULATION_OF_LEUKOCYTE_CELL_CELL_ADHESION",
"GOBP_POSITIVE_REGULATION_OF_CELL_KILLING",
"GOCC_MHC_PROTEIN_COMPLEX",
"GOMF_MHC_CLASS_II_RECEPTOR_ACTIVITY",
"GOCC_MHC_CLASS_II_PROTEIN_COMPLEX",
"GOBP_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_EXOGENOUS_PEPTIDE_ANTIGEN_VIA_MHC_CLASS_I_TAP_INDEPENDENT")

# Subset pathways
merge.results1 <- merge.results[merge.results$pathway %in% a1,]

# Rename pathways
merge.results1[merge.results1 == "IFNa_RO"] <- "IFNa response (Cilenti et all)"
merge.results1[merge.results1 == "HALLMARK_INTERFERON_GAMMA_RESPONSE"] <- "Hallmark_IFNg response"
merge.results1[merge.results1 == "GOMF_ANTIGEN_BINDING"] <- "Antigen Binding"
merge.results1[merge.results1 == "GOBP_POSITIVE_REGULATION_OF_LEUKOCYTE_CELL_CELL_ADHESION"] <- "Positive regulation of cell adhesion"
merge.results1[merge.results1 == "GOBP_POSITIVE_REGULATION_OF_CELL_KILLING"] <- "Positive regulation of cell killing"
merge.results1[merge.results1 == "GOCC_MHC_PROTEIN_COMPLEX"] <- "MHC protein complex"
merge.results1[merge.results1 == "GOMF_MHC_CLASS_II_RECEPTOR_ACTIVITY"] <- "MHC-II activity"
merge.results1[merge.results1 == "GOCC_MHC_CLASS_II_PROTEIN_COMPLEX"] <- "MHC-II protein complex"
merge.results1[merge.results1 == "GOBP_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_EXOGENOUS_PEPTIDE_ANTIGEN_VIA_MHC_CLASS_I_TAP_INDEPENDENT"] <- "Antigen processing and presentation"

# Order in the way we want to see
merge.results1$pathway <- factor(merge.results1$pathway, levels = c("IFNa response (Cilenti et all)",
                                                                   "Hallmark_IFNg response",
                                                                   "Positive regulation of cell adhesion",
                                                                   "Positive regulation of cell killing",
                                                                   "Antigen processing and presentation",
                                                                   "Antigen Binding",
                                                                   "MHC protein complex",
                                                                   "MHC-II protein complex",
                                                                   "MHC-II activity"))


#saveRDS(merge.results1, paste0(pdir, "/merge.results.for.GSEA.rds"))
# Load saved GSEA FILE --> KC, Monocytes and Macrophages vs OVA and OVA vs all with iterations 500.000
#merge.results1 <- readRDS(paste0(pdir, "/merge.results.for.GSEA.rds"))

merge.results1$origin <- factor(x = merge.results1$origin, levels = c("liOVA","OVA.IFNa","OVA.Il12","OVA.Combo"))

# Heatmap
y<-ggplot(merge.results1, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette="RdBu") +
  geom_text(aes(label = stats), vjust=0.7, angle=0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color="Black"),
        axis.text.x = element_text(angle=90, vjust=0.5, hjust=1, color="Black"),
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black"))+
  ggtitle("GSEA_MacroKCandmono vs OVA_Liver")
ggsave(filename = paste0(pdir, "/Liver_MacroKCsMonovsOVA_FigS2C.pdf"),
       plot=y, width=5, height=3)

# Unbias heatmap
merge.results <- merge.results[order(merge.results$padj, decreasing = F)]
merge.results_temp <-merge.results[merge.results$padj < 0.00001,]
filter_in <- head(unique(merge.results$pathway), 50)
filter_in <- unique(merge.results_temp$pathway)
merge.results2 <-merge.results[merge.results$pathway %in% filter_in,]
merge.results2$origin<- factor(x = merge.results2$origin, levels = c("liOVA","OVA.IFNa","OVA.Il12","OVA.Combo"))

y<-ggplot(merge.results2, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette = "RdBu") +
  geom_text(aes(label = stats), vjust = 0.7,angle = 0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"), text = element_text(size = 15), 
        axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1, color = "Black"), 
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black"))
ggtitle("GSEA_MacroKCandmono vs OVA_Tumor")
ggsave(filename = paste0(pdir, "/Liver_MacroKCsMonovsOVA_unbias.pdf"), plot=y, width=15, height=30) # limitsize = FALSE


##############TUMOR#####################
##############Figure S2D###############

macrophage.T<-subset(apcs.tumor, subset = NewlablesM_clu == "Monocytes" |
                       NewlablesM_clu == "Macrophages" |
                       NewlablesM_clu == "KCs")

macrophage.T<-SetIdent(macrophage.T, value = "RNA_Group")

combo<-FindMarkers(macrophage.T, ident.1="OVA.Combo", ident.2 ="liOVA", min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1) # used min.pct = -Inf or 0.01
IL12<-FindMarkers(macrophage.T, ident.1="OVA.Il12", ident.2 ="liOVA", min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
IFNa<-FindMarkers(macrophage.T, ident.1="OVA.Ifna", ident.2 ="liOVA", min.pct = 0.01, logfc.threshold = 0, min.cells.feature = 1, min.cells.group = 1)
OVA<-FindMarkers(macrophage.T, ident.1="liOVA",                      min.pct = 0.01, logfc.threshold = -0, min.cells.feature = 1, min.cells.group = 1)

combo.ranks <- combo$avg_log2FC
IL12.ranks <- IL12$avg_log2FC
IFNa.ranks <- IFNa$avg_log2FC
OVA.ranks <- OVA$avg_log2FC

names(combo.ranks) <- rownames(combo)
names(IL12.ranks) <- rownames(IL12)
names(IFNa.ranks) <- rownames(IFNa)
names(OVA.ranks) <- rownames(OVA)

res.combo<-fgsea(pathways = miDB_sig4.MLS, stats = combo.ranks, minSize=0, maxSize=500, eps=0)  # I added eps=0, before was nPermSimple=50000
res.IL12<-fgsea(pathways = miDB_sig4.MLS, stats = IL12.ranks, minSize=0, maxSize=500, eps=0)
res.IFNa<-fgsea(pathways = miDB_sig4.MLS, stats = IFNa.ranks, minSize=0, maxSize=500, eps=0)
res.OVA<-fgsea(pathways = miDB_sig4.MLS, stats = OVA.ranks, minSize=0, maxSize=500, eps=0) # before was nPermSimple=500000

#saveRDS(res.OVA, paste0(pdir, "FGSEA_KCmonoMacs_tumor_OVAvsAll_nperm500000.rds"))


# select the columns of interest
res.combo2<-res.combo[,c(1,3,6,8)]
res.IL122<-res.IL12[,c(1,3,6,8)]
res.IFNa2<-res.IFNa[,c(1,3,6,8)]
res.OVA2<-res.OVA[,c(1,3,6,8)]

# merge in a single file and save xlsx
merge1 <- merge(x=res.combo2,y=res.IL122,by="pathway", suffixes = c("-Combo", "-Il12"))
merge2 <- merge(x=res.IFNa2,y=res.OVA2,by="pathway", suffixes = c("-IFna", "-OVA"))
merge3 <- merge(x=merge1,y=merge2,by="pathway")

write.xlsx(merge3, paste0(pdir, "/GSEA_T_monomackc_vsOVA.xlsx"), asTable=T, rowNames=T) #save file


##################GSEA Heatmap of selected#######################################
# Rearrange data to plot heatmap
res.combo$origin<-"OVA.Combo"
res.IL12$origin<-"OVA.Il12"
res.IFNa$origin<-"OVA.IFNa"
res.OVA$origin<-"liOVA"

merge.results<-rbind(res.combo,res.IL12,res.IFNa,res.OVA)

# Create variable with star for statistic
merge.results$stats <- ifelse(merge.results$padj < 0.0005, "***",
                              ifelse(merge.results$padj < 0.005, "**",
                                     ifelse(merge.results$padj < 0.05, "*", "")))

# Manually selected pathways
a1<-c("IFNa_RO",
"HALLMARK_INTERFERON_GAMMA_RESPONSE",
"GOMF_ANTIGEN_BINDING",
"GOBP_POSITIVE_REGULATION_OF_LEUKOCYTE_CELL_CELL_ADHESION",
"GOBP_POSITIVE_REGULATION_OF_CELL_KILLING",
"GOCC_MHC_PROTEIN_COMPLEX",
"GOMF_MHC_CLASS_II_RECEPTOR_ACTIVITY",
"GOCC_MHC_CLASS_II_PROTEIN_COMPLEX",
"GOBP_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_EXOGENOUS_PEPTIDE_ANTIGEN_VIA_MHC_CLASS_I_TAP_INDEPENDENT")

# Subset selected pathways
merge.results1 <-merge.results[merge.results$pathway %in% a1,]

# Rename the pathways
merge.results1[merge.results1 == "IFNa_RO"] <- "IFNa response (Cilenti et all)"
merge.results1[merge.results1 == "HALLMARK_INTERFERON_GAMMA_RESPONSE"] <- "Hallmark_IFNg response"
merge.results1[merge.results1 == "GOMF_ANTIGEN_BINDING"] <- "Antigen Binding"
merge.results1[merge.results1 == "GOBP_POSITIVE_REGULATION_OF_LEUKOCYTE_CELL_CELL_ADHESION"] <- "Positive regulation of cell adhesion"
merge.results1[merge.results1 == "GOBP_POSITIVE_REGULATION_OF_CELL_KILLING"] <- "Positive regulation of cell killing"
merge.results1[merge.results1 == "GOCC_MHC_PROTEIN_COMPLEX"] <- "MHC protein complex"
merge.results1[merge.results1 == "GOMF_MHC_CLASS_II_RECEPTOR_ACTIVITY"] <- "MHC-II activity"
merge.results1[merge.results1 == "GOCC_MHC_CLASS_II_PROTEIN_COMPLEX"] <- "MHC-II protein complex"
merge.results1[merge.results1 == "GOBP_ANTIGEN_PROCESSING_AND_PRESENTATION_OF_EXOGENOUS_PEPTIDE_ANTIGEN_VIA_MHC_CLASS_I_TAP_INDEPENDENT"] <- "Antigen processing and presentation"

# Order in the way we want to see
merge.results1$pathway <- factor(merge.results1$pathway, levels = c("IFNa response (Cilenti et all)",
                                                                   "Hallmark_IFNg response",
                                                                   "Positive regulation of cell adhesion",
                                                                   "Positive regulation of cell killing",
                                                                   "Antigen processing and presentation",
                                                                   "Antigen Binding",
                                                                   "MHC protein complex",
                                                                   "MHC-II protein complex",
                                                                   "MHC-II activity"))

merge.results1$origin<- factor(x = merge.results1$origin, levels = c("liOVA","OVA.IFNa","OVA.Il12","OVA.Combo"))


# Heatmap
y<-ggplot(merge.results1, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette = "RdBu") +
  geom_text(aes(label = stats), vjust = 0.7,angle = 0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"),
        axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1, color = "Black"),
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black")) +
  ggtitle("GSEA_MacroKCandmono vs OVA_Tumor")
ggsave(filename = paste0(pdir, "/Tumor_MacroKCsMonovsOVA_FigS2D.pdf"), plot=y, width=5, height=3)

# Unbias heatmap
merge.results <- merge.results[order(merge.results$padj, decreasing = F)]
merge.results_temp <-merge.results[merge.results$padj < 0.00001,]
filter_in <- head(unique(merge.results_temp$pathway), 100)
merge.results2 <-merge.results[merge.results$pathway %in% filter_in,]
merge.results2$origin<- factor(x = merge.results2$origin, levels = c("liOVA","OVA.IFNa","OVA.Il12","OVA.Combo"))

y<-ggplot(merge.results2, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette = "RdBu") +
  geom_text(aes(label = stats), vjust=0.7, angle=0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"), text = element_text(size = 15), 
        axis.text.x = element_text(angle=90, vjust=0.5, hjust=1, color = "Black"), 
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black"))
  ggtitle("GSEA_MacroKCandmono vs OVA_Tumor")
ggsave(filename = paste0(pdir, "/Tumor_MacroKCsMonovsOVA_unbias.pdf"), plot=y, width=20, height=30) # limitsize = FALSE


##############ENDS here#####################################