library(Seurat)
library(openxlsx)
library(readxl)
library(tidyr)
library("RColorBrewer")
library(dplyr)
library(scRepertoire)
library(reshape2)
library(fgsea)
library(ggplot2)
library(matrixStats)
library(fmsb)

cluster_dir <- "/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/Analysis_MM/results3"
wdir<- paste0(cluster_dir, "/Result3_MNOT")
ldir<- paste0(cluster_dir, "/Liver_TandNK/")
tdir<- paste0(cluster_dir, "/Tumor_TandNK/")
pdir<- paste0(cluster_dir, "/Result3_MNOT/Plots")


#############################UPLOAD AND LABELLING LIVER###############
############Load LIVER object and add annotations###################
obs1 <- readRDS(paste0(ldir, "Liver_TandNK_final.rds"))
# Remove undefined
obs1 <- subset(obs1, subset=NewlablesM_clu != "undefined")

# Assign groups 
a1 <- grep(pattern = "Liver3",x = unique(obs1@meta.data$orig.ident),value=T)
obs1@meta.data$RNA_Group  [obs1@meta.data$orig.ident%in%a1]<- "OVA.IL12"
a1 <- grep(pattern = "Liver10",x = unique(obs1@meta.data$orig.ident),value=T)
obs1@meta.data$RNA_Group  [obs1@meta.data$orig.ident%in%a1]<- "OVA.IFNa"
a1 <- grep(pattern = "Liver11",x = unique(obs1@meta.data$orig.ident),value=T)
obs1@meta.data$RNA_Group  [obs1@meta.data$orig.ident%in%a1]<- "OVA"
a1 <- grep(pattern = "Liver9",x = unique(obs1@meta.data$orig.ident),value=T)
obs1@meta.data$RNA_Group  [obs1@meta.data$orig.ident%in%a1]<- "Combo"
#Tissue assign
a1 <- grep(pattern = "Liver",x = unique(obs1@meta.data$orig.ident),value=T)
obs1@meta.data$Tissue  [obs1@meta.data$orig.ident%in%a1]<- "Liver"
#sample origin
obs1$Tube <- paste0(obs1$RNA_Group,obs1$hash.ID)
obs1@meta.data$RNA_Group<- factor(x = obs1@meta.data$RNA_Group, levels = c("OVA","OVA.IFNa","OVA.IL12","Combo"))

# Create lables for all CD8 and CD4 T cells
obs1@meta.data$NewlablesG <- obs1@meta.data$NewlablesM_clu
obs1@meta.data$NewlablesG[grep("CD4",obs1@meta.data$NewlablesM_clu) ] <- "CD4 T cells"
obs1@meta.data$NewlablesG[grep("CD8",obs1@meta.data$NewlablesM_clu)] <- "CD8 T cells"

#create lables CD4 and CD8 clusters wothout naive
obs1@meta.data$NewlablesS <- obs1@meta.data$NewlablesM_clu
indCd4<- grepl("CD4",obs1@meta.data$NewlablesM_clu) & !grepl("Naive",obs1@meta.data$NewlablesM_clu)
indCd8<- grepl("CD8",obs1@meta.data$NewlablesM_clu) & !grepl("Naive",obs1@meta.data$NewlablesM_clu)
obs1@meta.data$NewlablesS[indCd4] <- "CD4 T cells"
obs1@meta.data$NewlablesS[indCd8] <- "CD8 T cells"
obs1@meta.data$NewlablesST <- paste0(obs1@meta.data$Tissue,".",obs1@meta.data$NewlablesS)

###################UPLOADING AND LABELLING TUMOR OBJECT#############################
####################################################################################
#Load
Tobs<- readRDS(paste0(tdir, "Tumor_TandNK_final.rds"))

a1 <- grep(pattern = "Tumor3",x = unique(Tobs@meta.data$orig.ident),value=T)
Tobs@meta.data$RNA_Group  [Tobs@meta.data$orig.ident%in%a1]<- "OVA.IL12"
a1 <- grep(pattern = "Tumor10",x = unique(Tobs@meta.data$orig.ident),value=T)
Tobs@meta.data$RNA_Group  [Tobs@meta.data$orig.ident%in%a1]<- "OVA.IFNa"
a1 <- grep(pattern = "Tumor11",x = unique(Tobs@meta.data$orig.ident),value=T)
Tobs@meta.data$RNA_Group  [Tobs@meta.data$orig.ident%in%a1]<- "OVA"
a1 <- grep(pattern = "Tumor34|Tumor29",x = unique(Tobs@meta.data$orig.ident),value=T)
Tobs@meta.data$RNA_Group  [Tobs@meta.data$orig.ident%in%a1]<- "Combo"
#Tissue Sample assign
Tobs$Tube <- paste0(Tobs$hash.ID,Tobs$RNA_Group)
#Ordering RNA_Group
Tobs@meta.data$RNA_Group<- factor(x = Tobs@meta.data$RNA_Group, levels = c("OVA","OVA.IFNa","OVA.IL12","Combo"))
Tobs@meta.data$Tissue<- "Tumor"

#create lables for all CD8 and CD4 t cells
Tobs@meta.data$NewlablesG <- Tobs@meta.data$NewlablesM_clu
Tobs@meta.data$NewlablesG[grep("CD4",Tobs@meta.data$NewlablesM_clu) ] <- "CD4 T cells"
Tobs@meta.data$NewlablesG[grep("CD8",Tobs@meta.data$NewlablesM_clu)] <- "CD8 T cells"

#create labels CD4 and CD8 clusters without naive
Tobs@meta.data$NewlablesS <- Tobs@meta.data$NewlablesM_clu
indCd4<- grepl("CD4",Tobs@meta.data$NewlablesM_clu) & !grepl("Naive",Tobs@meta.data$NewlablesM_clu)
indCd8<- grepl("CD8",Tobs@meta.data$NewlablesM_clu) & !grepl("Naive",Tobs@meta.data$NewlablesM_clu)
Tobs@meta.data$NewlablesS[indCd4] <- "CD4 T cells"
Tobs@meta.data$NewlablesS[indCd8] <- "CD8 T cells"
Tobs@meta.data$NewlablesST <- paste0(Tobs@meta.data$Tissue,".",Tobs@meta.data$NewlablesS)


###Calculating hyperexpanded T cells#############
##########LIVER##############################
obs1$aa3.Tube <- paste0(obs1$cdr3_aa2,".",obs1$Tube)
obs1$aa3.Tube[is.na(obs1$cdr3_aa2)] <- NA
obs1@meta.data$ClonoFreq <- obs1@meta.data %>% group_by(aa3.Tube) %>% mutate(count = n()) %>% ungroup() %>%
  as.data.frame() %>% select (count)
obs1@meta.data$ClonoFreq[is.na(obs1$cdr3_aa2),] <- NA

obs1@meta.data$Clonetype  <- NA
obs1@meta.data$Clonetype[obs1@meta.data$ClonoFreq==1] <- "unique"
obs1@meta.data$Clonetype[obs1@meta.data$ClonoFreq > 1 & obs1@meta.data$ClonoFreq <= 5] <- "small"
obs1@meta.data$Clonetype[obs1@meta.data$ClonoFreq > 5 & obs1@meta.data$ClonoFreq <= 30] <- "large"
obs1@meta.data$Clonetype[obs1@meta.data$ClonoFreq > 30] <- "hyperexpanded"

obs1$Clonetype <- factor(x = obs1$Clonetype, levels = c("unique", "small", "large", "hyperexpanded")) #order clonotype variable

##########TUMOR##############################
Tobs$aa3.Tube <- paste0(Tobs$cdr3_aa2,".",Tobs$Tube)
Tobs$aa3.Tube[is.na(Tobs$cdr3_aa2)] <- NA
Tobs@meta.data$ClonoFreq <- Tobs@meta.data  %>% group_by(aa3.Tube) %>% mutate(count = n()) %>% ungroup() %>%
  as.data.frame() %>% select (count)
Tobs@meta.data$ClonoFreq[is.na(Tobs$cdr3_aa2),] <- NA

Tobs@meta.data$Clonetype  <- NA
Tobs@meta.data$Clonetype[Tobs@meta.data$ClonoFreq==1] <- "unique"
Tobs@meta.data$Clonetype[Tobs@meta.data$ClonoFreq > 1 & Tobs@meta.data$ClonoFreq <= 5] <- "small"
Tobs@meta.data$Clonetype[Tobs@meta.data$ClonoFreq > 5 & Tobs@meta.data$ClonoFreq <= 30] <- "large"
Tobs@meta.data$Clonetype[Tobs@meta.data$ClonoFreq > 30] <- "hyperexpanded"

Tobs$Clonetype <- factor(x = Tobs$Clonetype, levels = c("unique", "small", "large", "hyperexpanded")) #order clonotype variable


############################################
######FINDING Tetramer reactive TCRs########
############################################
ind1 <- obs1$ADT.Tetramer
ind1 <- ind1[order(ind1)]

TetramerCount <- obs1@meta.data$ADT.Tetramer[!is.na(obs1@meta.data$ADT.Tetramer)]
TetramerCount <-TetramerCount[TetramerCount > 0]

obs1@meta.data$TetramerT <- "Other"
obs1@meta.data$TetramerT[obs1@meta.data$ADT.Tetramer>2] <- "OVA.TCR"

df1 <- data.frame(obs1$cdr3_aa2, obs1$TetramerT, obs1$ClonoFreq, obs1$Tissue)
df1$aa3.OVA <- paste0(obs1$cdr3_aa2,".",obs1$TetramerT)
df1 <- na.omit(df1)
df1l <- df1[df1$obs1.Tissue=="Liver",]
df2 <- df1l %>% group_by(aa3.OVA) %>% mutate(count = n()) %>% ungroup() %>% as.data.frame()
df3 <- df2 %>% select(obs1.cdr3_aa2,obs1.TetramerT,obs1.ClonoFreq,count) %>% unique() %>%
 pivot_wider(names_from = obs1.TetramerT, values_from = count) %>% as.data.frame()
df3[is.na(df3)] <- 0
df3$Tumor <- df3[,2]-df3[,3]-df3[,4]
OVA.TCRs <- df3$obs1.cdr3_aa2[df3[,4]/df3[,3]>1]

df1 <- data.frame(obs1$cdr3_aa2, obs1$TetramerT,obs1$ClonoFreq,obs1$Tissue,obs1$Tube)
df1$aa3.Tube <-paste0(obs1$cdr3_aa2,".",obs1$TetramerT,".",obs1$Tube)
df1 <- na.omit(df1)
df1l <- df1[df1$obs1.Tissue=="Liver",]
df2 <- df1l %>% group_by(aa3.Tube) %>% mutate(count = n()) %>% ungroup() %>% as.data.frame()
df3T <- df2 %>% select(obs1.cdr3_aa2,obs1.TetramerT,obs1.Tube,obs1.ClonoFreq,count) %>% unique() %>%
  pivot_wider(names_from = obs1.TetramerT, values_from = count) %>% as.data.frame()
df3T[is.na(df3T)] <- 0

######Indicating Tetramer OVA in liver
obs1$OVA.reactive <- ifelse(obs1$cdr3_aa2 %in% OVA.TCRs, "OVA", "Other")
obs1@meta.data$TetramerTS <- paste0(obs1@meta.data$OVA.reactive,".",obs1@meta.data$NewlablesS)
obs1$OVA.reactive.CD8 <- ifelse(obs1$OVA.reactive=="OVA" & obs1$NewlablesG=="CD8 T cells", "OVA", "Other")

######Indicating Tetramer OVA in tumor
Tobs$OVA.reactive <- ifelse(Tobs$cdr3_aa2 %in% OVA.TCRs, "OVA", "Other")
Tobs@meta.data$TetramerTS <- paste0(Tobs@meta.data$OVA.reactive,".",Tobs@meta.data$NewlablesS)
Tobs$OVA.reactive.CD8 <- ifelse(Tobs$OVA.reactive=="OVA" & Tobs$NewlablesG=="CD8 T cells", "OVA", "Other")


######TISSUE SHARED CLONOTYPES with tumors########
# clonotypes in Liver
df1<-data.frame(obs1@meta.data$cdr3_aa2,obs1@meta.data$hash.ID,obs1@meta.data$RNA_Group, obs1@meta.data$Tissue)
df2<-na.omit(df1)
df2$cdr3_mouse<-paste0(df2$obs1.meta.data.cdr3_aa2,".",df2$obs1.meta.data.hash.ID,".",df2$obs1.meta.data.RNA_Group)

# clonotypes in Tumor
df3<-data.frame(Tobs@meta.data$cdr3_aa2,Tobs@meta.data$hash.ID,Tobs@meta.data$RNA_Group, Tobs@meta.data$Tissue)
df4<-na.omit(df3)
df4$cdr3_mouse<-paste0(df4$Tobs.meta.data.cdr3_aa2,".",df4$Tobs.meta.data.hash.ID,".",df4$Tobs.meta.data.RNA_Group)

# List of Shared clonotypes
shared_cdr3aa <- intersect(df2$cdr3_mouse, df4$cdr3_mouse)

# Add variable shared in liver
obs1$cdr3_mouse<-paste0(obs1$cdr3_aa2,".",obs1$hash.ID,".",obs1$RNA_Group)
obs1$Shared <- ifelse(obs1$cdr3_mouse %in% shared_cdr3aa, "Shared", "Unique")

# Add variable shared in tumor
Tobs$cdr3_mouse<-paste0(Tobs$cdr3_aa2,".",Tobs$hash.ID,".",Tobs$RNA_Group)
Tobs$Shared <- ifelse(Tobs$cdr3_mouse %in% shared_cdr3aa, "Shared", "Unique")


# Add new variables in liver 
obs1@meta.data$New_division <- obs1@meta.data$NewlablesM_clu
ind<- grepl("CD4",obs1@meta.data$NewlablesM_clu) & grepl("Shared",obs1@meta.data$Shared)
obs1@meta.data$New_division[ind] <- "Shared CD4"
ind<- grepl("CD8",obs1@meta.data$NewlablesM_clu) & grepl("Shared",obs1@meta.data$Shared)
obs1@meta.data$New_division[ind] <- "Shared CD8"
ind<- grepl("CD8",obs1@meta.data$NewlablesM_clu) & grepl("OVA",obs1@meta.data$OVA.reactive)
obs1@meta.data$New_division[ind] <- "OVA.reactive"
obs1@meta.data$New_division2 <- "Other"
ind<- grepl("CD4",obs1@meta.data$NewlablesM_clu) & grepl("Shared",obs1@meta.data$Shared)
obs1@meta.data$New_division2[ind] <- "Shared CD4"

# Variable with shared CD4 only in selected groups
obs1$New_division3<-paste0(obs1$New_division2,".",obs1$RNA_Group)
obs1@meta.data$New_division3[obs1@meta.data$New_division3 %in% "Shared CD4.OVA.IFNa"] <- "Other.OVA.IFNa"
obs1@meta.data$New_division3[obs1@meta.data$New_division3 %in% "Shared CD4.OVA"] <- "Other.OVA"


# Add new variables in tumor
Tobs@meta.data$New_division <- Tobs@meta.data$NewlablesM_clu
ind<- grepl("CD4",Tobs@meta.data$NewlablesM_clu) & grepl("Shared",Tobs@meta.data$Shared)
Tobs@meta.data$New_division[ind] <- "Shared CD4"
ind<- grepl("CD8",Tobs@meta.data$NewlablesM_clu) & grepl("Shared",Tobs@meta.data$Shared)
Tobs@meta.data$New_division[ind] <- "Shared CD8"
ind<- grepl("CD8",Tobs@meta.data$NewlablesM_clu) & grepl("OVA",Tobs@meta.data$OVA.reactive)
Tobs@meta.data$New_division[ind] <- "OVA.reactive"
Tobs@meta.data$New_division2 <- "Other"
ind<- grepl("CD4",Tobs@meta.data$NewlablesM_clu) & grepl("Shared",Tobs@meta.data$Shared)
Tobs@meta.data$New_division2[ind] <- "Shared CD4"


#######################Plot UMAP################

table(obs1$OVA.reactive.CD8, obs1$NewlablesG)

# Save plot
pdf(paste0(pdir, "/TandNK_umap_Fig3A.pdf"), width=7, height=6) # Figure 3A
DimPlot(obs1, reduction = "umap.harmony.orig.ident",group.by = "NewlablesM_clu", pt.size = 0.5, label = T, label.size = 3, repel = T)
dev.off()
pdf(paste0(pdir, "/tetramer_umap_Fig3E.pdf"), width=7, height=6) # Figure 3E
DimPlot(obs1, reduction = "umap.harmony.orig.ident",group.by = "OVA.reactive.CD8", pt.size = 0.5, label = F, order = c("OVA", "Others"), cols = c("lightgrey", "blue"))
dev.off()
pdf(paste0(pdir, "/shared_cd4_umap_Fig3I.pdf"), width=7, height=6) # Figure 3I
DimPlot(obs1, reduction = "umap.harmony.orig.ident",group.by = "New_division2", pt.size = 0.5, label = F, order = c("Shared CD4", "Others"), cols = c("lightgrey", "blue"))
dev.off()

# Export DimPlot as excel
var_list <- c("UMAPh_1", "UMAPh_2","Tissue","orig.ident","Sample","RNA_Group","Tube","RNA_snn_h.orig.ident_res.1.2","NewlablesM_clu","Shared","OVA.reactive.CD8","New_division2")
TandNK_df <- FetchData(obs1, vars = var_list)
TandNK_df$cell_ID <- rownames(TandNK_df)
write.xlsx(TandNK_df, file=paste0(pdir, "/TandNK_umap_Fig3A_3E_3I.xlsx"), overwrite=T)

#######################Plot UMAP################

# # NO_TCR
# # Save plot
# pdf(paste0(pdir, "/TandNK_umap_NO_TCR_FigS13C-1.pdf"), width=7, height=6) # Figure S13C-1
# DimPlot(obs1, reduction = "umap.harmony.orig.ident",group.by = "NewlablesM_clu", pt.size = 0.5, label = T, label.size = 3, repel = T)
# dev.off()
# pdf(paste0(pdir, "/tetramer_umap_NO_TCR_FigS13C-2.pdf"), width=7, height=6) # Figure S13C-2
# DimPlot(obs1, reduction = "umap.harmony.orig.ident",group.by = "OVA.reactive.CD8", pt.size = 0.5, label = F, order = c("OVA", "Others"), cols = c("lightgrey", "blue"))
# dev.off()
# 
# # Export DimPlot as excel
# var_list <- c("UMAPh_1", "UMAPh_2","Tissue","orig.ident","Sample","RNA_Group","Tube","RNA_snn_h.orig.ident_res.1.2","NewlablesM_clu","Shared","OVA.reactive.CD8","New_division2")
# TandNK_df <- FetchData(obs1, vars = var_list)
# TandNK_df$cell_ID <- rownames(TandNK_df)
# write.xlsx(TandNK_df, file=paste0(pdir, "/TandNK_umap_NO_TCR_FigS13C.xlsx"), overwrite=T)


##############################################################################
################Figure S3A - Cluster dotplot markers##########################
obs1@meta.data$NewlablesM_clu_temp <- obs1@meta.data$NewlablesM_clu
new_order <- c("Naive CD8","Naive CD4","CD4 Treg","Th17 CD4","NK","Cytotox NK",
                "Early CD8","CD8 prol","CD8 Teff1","CD8 Teff2","CD8 Teff3",
                "Act gd T ","gd T","ILC-like","ILCs","IFNg CD4","Il4 CD4")
obs1@meta.data$NewlablesM_clu <- factor(x = obs1@meta.data$NewlablesM_clu, levels = new_order)

#t<-as.matrix(table(obs1$NewlablesM_clu))
#as.vector(unique(Idents(obs1)))
#setdiff(new_order, as.vector(unique(Idents(obs1))))

#Code to select top scoring and selective genes for each cluster
obs1<-SetIdent(obs1, value = "NewlablesM_clu")
markers<- FindAllMarkers(obs1)
#write.xlsx(markers, file=paste0(pdir, "/Markers_Newlables_clu.xlsx"),asTable=T,rowNames=T) # save file
markers$diff<-markers$pct.1-markers$pct.2 #add diff variable to select most selective genes
top_genes_per_cluster <- c()
for (i in unique(markers$cluster)) {
  cluster_genes <- markers[markers$cluster == i,] # select cluster i
  cluster_genes<-cluster_genes[rev(order(cluster_genes$diff)),] #order by diff ptc1-ptc2
  top_genes <- cluster_genes$gene[(1:3)] #select top scoring 1:n
  top_genes_per_cluster <- c(top_genes_per_cluster,top_genes)
}

manual_genes<-c("Il4","Tbx21","Rorc","Il17a","Foxp3","Ifng","Mki67",
                "Gzmb","Tox","Pdcd1")

features_to_plot <- unique(c(top_genes_per_cluster, manual_genes))
print(features_to_plot)

paletteLength <- 100
myColor <- colorRampPalette(c("blue", "darkgrey", "darkred"))(paletteLength)

pdf(paste0(pdir, "/dotplot.markers.clusters.livercd8_not_clustered_Fig.S3A.pdf"), width=10, height=5)
a5<-scCustomize::Clustered_DotPlot(obs1,
                                   features = features_to_plot,
                                   plot_km_elbow=F,
                                   row_label_size=10,
                                   flip=T, colors_use_exp = myColor,
                                   cluster_feature=F, cluster_ident=F)
dev.off()

pdf(paste0(pdir, "/dotplot.markers.clusters.livercd8_Fig.S3A.pdf"), width=10, height=5)
a5<-scCustomize::Clustered_DotPlot(obs1,
                                   features = features_to_plot,
                                   plot_km_elbow=F,
                                   row_label_size=10,
                                   flip=T, colors_use_exp = myColor,
                                   cluster_feature=T, cluster_ident=T)
dev.off()

##########################################################
####DOTPLOT WITH STATISTIC FROM LIVER####

# The function PlotStellare is in the script plot_stellare_function.R
# Figures 3D and S3C
pdf(paste0(pdir, "/Dotplot_stellare_CD8_liver_Fig3D.pdf"), width=12, height=3) # Figure 3D
PlotStellare(obs1=obs1, features1=featuresCD8, valueG="NewlablesG", i="CD8 T cells", group.by0 ="RNA_Group", controGroup="OVA")
dev.off()

pdf(paste0(pdir, "/Dotplot_stellare_tetramer_liver_FigS3C.pdf"), width=12, height=3) # Figure S3C
PlotStellare(obs1=obs1, features1=featuresCD8, valueG="OVA.reactive.CD8", i="OVA", group.by0 ="RNA_Group", controGroup="OVA")
dev.off()


########################################
####Figure 3J - TABLE POP PERCENTAGE CD4
CD4 <- subset(obs1, subset = NewlablesG=="CD4 T cells")

liver.CD4_cells <- table(CD4$Tube, CD4$NewlablesM_clu)
liver.CD4_percentage <- round(prop.table(table(CD4$Tube, CD4$NewlablesM_clu), 1)*100, 2)
write.xlsx(liver.CD4_cells, file=paste0(pdir, "/liver.CD4.prop.number.xlsx"))
write.xlsx(liver.CD4_percentage, file=paste0(pdir, "/liver.CD4.prop.percentage.tube.xlsx"))

####Figure 3K - clonal expansion CD4
liver.CD4_group_cells <- table(CD4$RNA_Group, CD4$Clonetype)
liver.CD4_group_percentage <- round(prop.table(table(CD4$RNA_Group, CD4$Clonetype), 1)*100, 2)
write.xlsx(liver.CD4_group_percentage, file=paste0(pdir, "/liver.CD4.clonotypes.xlsx"))


#####################Figure S3D - Plot of shared CD4 in different groups#############
features1<-c("Stat1","Ly6c2","Oas1a","Irf8","Ifitm3", #Ifna
             "Il18rap","Il18r1","Il12rb1","Gbp2", #Ifng genes 
             "Ifng","Tnf","Il21","Gzmk","Fasl","Cd40lg","Slamf1", #Th1/effector genes
             "Il10","Foxp3","Pdcd1","Ctla4","Tnfrsf18","Tigit","Tox") #immune suppression

CD4$New_division3<- factor(x = CD4$New_division3, levels = c("Other.OVA","Other.OVA.IFNa","Other.OVA.IL12","Shared CD4.OVA.IL12","Other.Combo","Shared CD4.Combo"))
CD4_shared<-subset(CD4, subset= RNA_Group == "Combo"|
                     RNA_Group =="OVA.IL12")

CD4_shared<-SetIdent(CD4_shared, value = "New_division3")

CD4_shared<-SetIdent(CD4_shared, value = "Tissue")
i <- unique(CD4_shared$Tissue)[1]

pa1 <- DotPlot(CD4_shared, features = features1,idents = i, dot.scale=15,split.by = "New_division3",
               cols="RdBu")+RotatedAxis()
df1 <- pa1$data
df1$id <-  factor(x = df1$id, levels = unique(df1$id)[c(4,1,2,3)])

m.Combo <- FindMarkers(CD4_shared, ident.1 = "Shared CD4.Combo", ident.2="Other.Combo", group.by = "New_division3",
                       subset.ident = i,features = features1,
                       min.pct = 0.01, logfc.threshold = 0, min.cells.feature=1, min.cells.group=1)
m.Combo <- m.Combo[match(features1,rownames(m.Combo)),]

other.Combo <- FindMarkers(CD4_shared, ident.1 = "Other.Combo", ident.2="Shared CD4.Combo", group.by = "New_division3",
                           subset.ident = i,features = features1,
                           min.pct = 0.01, logfc.threshold = 0, min.cells.feature=1, min.cells.group=1)
other.Combo <- other.Combo[match(features1,rownames(other.Combo)),]

m.IL12 <- FindMarkers(CD4_shared, ident.1 = "Shared CD4.OVA.IL12", ident.2 = "Other.OVA.IL12", group.by = "New_division3",
                      subset.ident = i,features = features1,
                      min.pct = 0.01, logfc.threshold = 0, min.cells.feature=1, min.cells.group=1)
m.IL12 <- m.IL12[match(features1,rownames(m.IL12)),]
other.IL12 <- FindMarkers(CD4_shared, ident.1 = "Other.OVA.IL12", ident.2 = "Shared CD4.OVA.IL12", group.by = "New_division3",
                          subset.ident = i,features = features1,
                          min.pct = 0.01, logfc.threshold = 0, min.cells.feature=1, min.cells.group=1)
other.IL12 <- other.IL12[match(features1,rownames(other.IL12)),]

other.IL12$p_val_adj<-1
other.Combo$p_val_adj<-1

markers1 <- rbind(other.IL12,m.IL12,other.Combo,m.Combo)

df2 <- cbind(df1,markers1)
df2$stars <-  ifelse(df2$p_val_adj< 0.001,"***",
                     ifelse(df2$p_val_adj< 0.01,"**",
                            ifelse(df2$p_val_adj< 0.05,"*","")))


df2$id <- factor(x = df2$id, levels = c("Liver_Other.OVA.IL12","Liver_Shared CD4.OVA.IL12","Liver_Other.Combo","Liver_Shared CD4.Combo"))

a<-ggplot(df2, aes(y=id, x=features.plot, size=pct.exp ,color=avg.exp.scaled)) + 
  geom_point() +
  scale_size_area(max_size=15) +
  scale_colour_gradient2(low= "blue",mid = "darkgrey",high="darkred") +    ####"#CCCCFF"
  labs(y='',x='')+
  geom_text(aes(label=stars, vjust=0.8), col="black", size=4)+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"),
        axis.text.x = element_text(angle = 45, hjust= 1, color = "Black"),
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black"))+
  ggtitle("Dotplot Shared CD4")
ggsave(filename = paste0(pdir, "/Dotplot_stellare_CD4.shared_FigS3D.pdf"),
       plot=a, width=11, height=3) # Figure S3D


##########################GSEA#########################################
##################Figure 3B FGSEA on all TandNK########################
# Load signature
#miDB_sig4.MLS <- readRDS(paste0(username, "90-756142658_RNAseq_Squadrito/05-DGE-Tumor/miDB_sig4.MLS.rds"))
miDB_sig4.MLS <- readRDS("/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A018/reference/miDB_sig4.MLS.rds")

obs1<-SetIdent(obs1, value = "RNA_Group")
combo<-FindMarkers(obs1, ident.1="Combo",   ident.2 ="OVA", min.pct=0.01, logfc.threshold=0)
IL12<-FindMarkers(obs1, ident.1="OVA.IL12", ident.2 ="OVA", min.pct=0.01, logfc.threshold=0)
IFNa<-FindMarkers(obs1, ident.1="OVA.IFNa", ident.2 ="OVA", min.pct=0.01, logfc.threshold=0)
OVA<-FindMarkers(obs1, ident.1="OVA",                       min.pct=0.01, logfc.threshold=0)

combo.ranks <- combo$avg_log2FC
IL12.ranks <- IL12$avg_log2FC
IFNa.ranks <- IFNa$avg_log2FC
OVA.ranks <- OVA$avg_log2FC

names(combo.ranks) <- rownames(combo)
names(IL12.ranks) <- rownames(IL12)
names(IFNa.ranks) <- rownames(IFNa)
names(OVA.ranks) <- rownames(OVA)

res.combo<-fgsea(pathways = miDB_sig4.MLS, stats = combo.ranks, minSize=0, maxSize=500, eps=0)
res.IL12<-fgsea(pathways = miDB_sig4.MLS, stats = IL12.ranks, minSize=0, maxSize=500, eps=0)
res.OVA<-fgsea(pathways = miDB_sig4.MLS, stats = OVA.ranks, minSize=0, maxSize=500, eps=0) #nPermSimple = 500000
res.IFNa<-fgsea(pathways = miDB_sig4.MLS, stats = IFNa.ranks, minSize=0, maxSize=500, eps=0)

#select columns of interest
res.combo2<-res.combo[,c(1,3,6,8)]
res.IL122<-res.IL12[,c(1,3,6,8)]
res.IFNa2<-res.IFNa[,c(1,3,6,8)]
res.OVA2<-res.OVA[,c(1,3,6,8)]

# merge in a single file and save xlsx
# merge1 <- merge(x=res.combo2,y=res.IL122,by="pathway", suffixes = c("-Combo", "-Il12"))
# merge2 <- merge(x=res.IFNa2,y=res.OVA2,by="pathway", suffixes = c("-IFna", "-OVA"))
# merge3<-merge(x=merge1,y=merge2,by="pathway")
# write.xlsx(merge3,paste0(pdir "/GSEA_L_allTnK.xlsx"),asTable = TRUE,rowNames=T) ####save file

#rearrange data to plot heatmap
res.combo$origin<-"OVA.Combo"
res.IL12$origin<-"OVA.Il12"
res.IFNa$origin<-"OVA.IFNa"
res.OVA$origin<-"liOVA"

merge.results<-rbind(res.combo,res.IL12,res.IFNa,res.OVA)

#create variable with star for statistic
merge.results$stats <- ifelse(merge.results$padj < 0.0005, "***",
                              ifelse(merge.results$padj < 0.005, "**",
                                     ifelse(merge.results$padj < 0.05, "*", "")))


#pathway manually selected
a1<-c("GOBP_NEGATIVE_REGULATION_OF_VIRAL_GENOME_REPLICATION",
      "GOBP_RESPONSE_TO_TYPE_I_INTERFERON",
      "GOBP_CELL_DIVISION",
      "GOBP_RESPONSE_TO_INTERFERON_GAMMA",
      "GOBP_POSITIVE_REGULATION_OF_CELL_CYCLE_PROCESS")

# Subset selected pathways
merge.results1 <-merge.results[merge.results$pathway %in% a1,]

# Rename pathways
merge.results1[merge.results1 == "GOBP_RESPONSE_TO_TYPE_I_INTERFERON"] <- "Response to IFNa"
merge.results1[merge.results1 == "GOBP_CELL_DIVISION"] <- "Cell division"
merge.results1[merge.results1 == "GOBP_NEGATIVE_REGULATION_OF_VIRAL_GENOME_REPLICATION"] <- "Negative regulation of viral replication"
merge.results1[merge.results1 == "GOBP_RESPONSE_TO_INTERFERON_GAMMA"] <- "Response to IFNg"
merge.results1[merge.results1 == "GOBP_POSITIVE_REGULATION_OF_CELL_CYCLE_PROCESS"] <- "Positive regulation of proliferation"

# Order in the way we want to see
merge.results1$pathway<- factor(merge.results1$pathway, levels = rev(c("Response to IFNa",
                                                                   "Response to IFNg",
                                                                   "Negative regulation of viral replication",
                                                                   "Positive regulation of proliferation",
                                                                   "Cell division")))

merge.results1$origin<- factor(x = merge.results1$origin, levels = c("liOVA","OVA.IFNa","OVA.Il12","OVA.Combo"))

#Heatmap
y<-ggplot(merge.results1, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette = "RdBu") +
  geom_text(aes(label = stats), vjust=0.7,angle=0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"),
        axis.text.x = element_text(angle = 45, hjust=1, color = "Black"),
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black")) +
  ggtitle("GSEA_TandNK_Specific")
ggsave(filename = paste0(pdir, "/GSEA_heatmap_TandNK_Fig3B.pdf"), plot=y, width=5, height=3)

# Unbias heatmap
merge.results <- merge.results[order(merge.results$padj, decreasing = F)]
merge.results_temp <-merge.results[merge.results$padj < 0.00001,]
filter_in <- head(unique(merge.results$pathway), 50)
filter_in <- unique(merge.results_temp$pathway)
merge.results2 <-merge.results[merge.results$pathway %in% filter_in,]
merge.results2$origin<- factor(x = merge.results2$origin, levels = c("liOVA","OVA.IFNa","OVA.Il12","OVA.Combo"))

y<-ggplot(merge.results2, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette = "RdBu") +
  geom_text(aes(label = stats), vjust = 0.7,angle = 0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"), text = element_text(size = 15), 
        axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1, color = "Black"), 
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black")) +
ggtitle("GSEA_TandNK_Specific")
ggsave(filename = paste0(pdir, "/GSEA_heatmap_TandNK_unbias.pdf"), plot=y, width=15, height=30) # limitsize = FALSE


###############Figure 3F  Only OVA Specific#####
tetramer.t<-subset(obs1, subset = OVA.reactive== "OVA" &
                     NewlablesG =="CD8 T cells")
tetramer.t<-SetIdent(tetramer.t, value = "RNA_Group")

combo<-FindMarkers(tetramer.t, ident.1="Combo",   ident.2 ="OVA", min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)
IL12<-FindMarkers(tetramer.t, ident.1="OVA.IL12", ident.2 ="OVA", min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)
IFNa<-FindMarkers(tetramer.t, ident.1="OVA.IFNa", ident.2 ="OVA", min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)
OVA<-FindMarkers(tetramer.t, ident.1="OVA",                       min.pct=0.01, logfc.threshold=0, min.cells.feature=1, min.cells.group=1)

combo.ranks <- combo$avg_log2FC
IL12.ranks <- IL12$avg_log2FC
IFNa.ranks <- IFNa$avg_log2FC
OVA.ranks <- OVA$avg_log2FC

names(combo.ranks) <- rownames(combo)
names(IL12.ranks) <- rownames(IL12)
names(IFNa.ranks) <- rownames(IFNa)
names(OVA.ranks) <- rownames(OVA)
res.combo <- fgsea(pathways = miDB_sig4.MLS, stats = combo.ranks, minSize=0, maxSize=500, eps=0) # I added eps=0
res.IL12  <- fgsea(pathways = miDB_sig4.MLS, stats = IL12.ranks,  minSize=0, maxSize=500, eps=0) # nPermSimple = 500000
res.OVA   <- fgsea(pathways = miDB_sig4.MLS, stats = OVA.ranks,   minSize=0, maxSize=500, eps=0) # nPermSimple = 500000 
res.IFNa  <- fgsea(pathways = miDB_sig4.MLS, stats = IFNa.ranks,  minSize=0, maxSize=500, eps=0)

# saveRDS(res.OVA, paste0(pdir, "/FGSEA_L_tetramer_OVA-vsALL_nperm500000.rds"))
# saveRDS(res.IL12, paste0(pdir, "/FGSEA_L_tetramer_IL12-vsOVA_nperm500000.rds"))

# Select colums of interest
res.combo2<-res.combo[,c(1,3,6,8)]
res.IL122<-res.IL12[,c(1,3,6,8)]
res.IFNa2<-res.IFNa[,c(1,3,6,8)]
res.OVA2<-res.OVA[,c(1,3,6,8)]

# Merge in a single file and save xlsx
merge1 <- merge(x=res.combo2,y=res.IL122,by="pathway", suffixes = c("-Combo", "-Il12"))
merge2 <- merge(x=res.IFNa2,y=res.OVA2,by="pathway", suffixes = c("-IFna", "-OVA"))
merge3<-merge(x=merge1,y=merge2,by="pathway")
# write.xlsx(merge3,"GSEA_L_tetramer.immunedb.xlsx",asTable = TRUE,rowNames=T) ####save file

####rearrange to plot
res.combo$origin<-"OVA.Combo"
res.IL12$origin<-"OVA.Il12"
res.IFNa$origin<-"OVA.IFNa"
res.OVA$origin<-"liOVA"

merge.results<-rbind(res.combo,res.IL12,res.IFNa,res.OVA)

#create variable with star for statistic
merge.results$stats <- ifelse(merge.results$padj < 0.0005, "***",
                              ifelse(merge.results$padj < 0.005, "**",
                                     ifelse(merge.results$padj < 0.05, "*", "")))

#merge.results2 <- merge.results[order(merge.results$padj, decreasing = F)]
#filter_in <- head(unique(merge.results2$pathway), 40)
#merge.results1 <-merge.results[merge.results$pathway %in% filter_in,]

# Manually selected pathways
a1_OLD<-c("Exhaustion_Wherry",
"GOBP_RESPONSE_TO_TYPE_I_INTERFERON",
"GOBP_POSITIVE_REGULATION_OF_RESPONSE_TO_INTERFERON_GAMMA",
"GOCC_IMMUNOLOGICAL_SYNAPSE",
"GOBP_POSITIVE_REGULATION_OF_CELL_KILLING",
"GOBP_ALPHA_BETA_T_CELL_PROLIFERATION",
"GOBP_RESPONSE_TO_INTERLEUKIN_15")

a1<-c("Exhaustion_Wherry",
      "HALLMARK_INTERFERON_ALPHA_RESPONSE",
      "HALLMARK_INTERFERON_GAMMA_RESPONSE",
      "GOBP_RESPONSE_TO_TYPE_I_INTERFERON",
      "GOBP_RESPONSE_TO_VIRUS",
      "LPS_RO")

# Subset selected pathways
merge.results1 <-merge.results[merge.results$pathway %in% a1,]

# Rename pathways
merge.results1[merge.results1 == "HALLMARK_INTERFERON_ALPHA_RESPONSE"] <- "Response to IFNa"
merge.results1[merge.results1 == "HALLMARK_INTERFERON_GAMMA_RESPONSE"] <- "Response to IFNg"
merge.results1[merge.results1 == "GOBP_RESPONSE_TO_TYPE_I_INTERFERON"] <- "Response to type-I interferon"
merge.results1[merge.results1 == "GOBP_RESPONSE_TO_VIRUS"] <- "Response to virus"
merge.results1[merge.results1 == "Exhaustion_Wherry"] <- "Exhaustion signature (Wherry)"
merge.results1[merge.results1 == "LPS_RO"] <- "LPS signature from Cilenti et al"
#merge.results1[merge.results1 == "GOBP_TISSUE_MIGRATION"] <- "Tissue migration"
#merge.results1[merge.results1 == "GOBP_CELLULAR_AMINO_ACID_CATABOLIC_PROCESS"] <- "Amino acid catabolic process"
#merge.results1[merge.results1 == "GOBP_MESENCHYMAL_CELL_DIFFERENTIATION"] <- "Mesenchymal cell differentiation"
#merge.results1[merge.results1 == "GOBP_REGULATION_OF_VASCULATURE_DEVELOPMENT"] <- "regulation of vasculature development"

# Order in the way we want to see
merge.results1$pathway <- factor(merge.results1$pathway, levels = rev(c("Response to virus",
                                                                    "Response to IFNa",
                                                                    "Response to IFNg",
                                                                    "Response to type-I interferon",
                                                                    "LPS signature from Cilenti et al",
                                                                    "Exhaustion signature (Wherry)")))

merge.results1$origin <- factor(x = merge.results1$origin, levels = c("liOVA","OVA.IFNa","OVA.Il12","OVA.Combo"))

# saveRDS(merge.results1, paste0(pdir, "/GSEA_Tetramer_vsOVA.rds"))
# merge.results1<-readRDS(paste0(pdir, "/GSEA_Tetramer_vsOVA.rds"))

# GSEA heatmap
y<-ggplot(merge.results1, aes (x=origin, y=pathway, fill=NES)) +  # y=reorder(pathway, pval, decreasing=T)
  geom_tile() +
  scale_fill_distiller(palette = "RdBu") +
  geom_text(aes(label=stats), vjust=0.7,angle=0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y=element_text(color = "Black"),
        axis.text.x=element_text(angle=45, hjust=1, color="Black"),
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black")) +
  ggtitle("GSEA_OVA_Specific")
ggsave(filename = paste0(pdir, "/GSEA_heatmap_OVA_Specific_Fig3F_new.pdf"), plot=y, width=5.5, height=4) # width=5, height=3)

# Unbias heatmap
merge.results <- merge.results[order(merge.results$padj, decreasing = F)]
merge.results_temp <-merge.results[merge.results$padj < 0.00001,]
filter_in <- head(unique(merge.results$pathway), 50)
#filter_in <- unique(merge.results_temp$pathway)
merge.results2 <-merge.results[merge.results$pathway %in% filter_in,]
merge.results2$origin<- factor(x = merge.results2$origin, levels = c("liOVA","OVA.IFNa","OVA.Il12","OVA.Combo"))

y<-ggplot(merge.results2, aes (x=origin, y=pathway, fill=NES)) + 
  geom_tile() +
  scale_fill_distiller(palette = "RdBu") +
  geom_text(aes(label = stats), vjust=0.7, angle=0) +
  labs(y='',x='')+
  theme_classic()+
  theme(axis.text.y = element_text(color = "Black"), text = element_text(size = 15), 
        axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1, color = "Black"), 
        axis.line.x=element_line(color="Black"),
        axis.line.y=element_line(color="Black")) +
ggtitle("GSEA_OVA_Specific")
ggsave(filename = paste0(pdir, "/GSEA_heatmap_OVA_Specific_unbias.pdf"), plot=y, width=15, height=30) # limitsize = FALSE



########################RADAR PLOT######################
##################Figure 3C RADAR PLOT CD8########################

CD8 <- subset(obs1, subset = NewlablesG=="CD8 T cells")

Effector <- list(c("Gzmb","Gzma","Prf1","Ifng","Tnf","Fasl"))
Pex <- list( c("Tbx21","Klrg1","Cx3cr1","Tcf7","Klf2","Sell"))
Exhaustion <- list(c("Pdcd1","Lag3","Ctla4","Havcr2","Tigit","Il10ra","Tox"))
IFNa_genes <- list(c("Stat1","Ly6c2","Oas1a","Irf8","Ifitm3") )
IFNg_genes <-list(c("Il18rap","Il18r1","Ifngas1","Il12rb1","Gbp2"))


CD8 <- AddModuleScore(CD8, features = Effector,   name = "Effector")
CD8 <- AddModuleScore(CD8, features = Pex,        name = "Pex")
CD8 <- AddModuleScore(CD8, features = Exhaustion, name = "Exhaustion")
CD8 <- AddModuleScore(CD8, features = IFNa_genes, name = "IFNa_genes")
CD8 <- AddModuleScore(CD8, features = IFNg_genes, name = "IFNg_genes")

#Normalize data
#we needed to find a way to normalize the module scores. 
#we used a quantile normalization method.

M1<-CD8@meta.data[,c("NewlablesM_clu", "RNA_Group", "Effector1","Pex1","Exhaustion1","IFNa_genes1","IFNg_genes1")]
#M1<-CD8@meta.data[,c(41, 42, 60:64)]
M1[,3:7]<-limma::normalizeQuantiles(M1[,3:7])
Groups <-unique(CD8$RNA_Group)
CellType<-unique(M1$NewlablesM_clu)


lsCells <- grep(".db",ls(),value=T)
MinMax<-lapply(lsCells,get)
max1 <- rep(do.call("max", MinMax),5)
min1 <- rep(do.call("min", MinMax),5)

colors_border=c(rgb(0,0,0,0.9), rgb(0.1,0.6,0.2,0.9), rgb(0.8,0.1,0.1,0.9), rgb(0.1,0.2,1,0.9))
colors_in=c(rgb(0,0,0,0.1), rgb(0.1,0.6,0.2,0.1), rgb(0.8,0.1,0.1,0.1), rgb(0.1,0.2,1,0.1))


M2<-M1
M3a<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[1],3:7]),na.rm=T)
M3b<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[2],3:7]),na.rm=T)
M3c<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[3],3:7]),na.rm=T)
M3d<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[4],3:7]),na.rm=T)
M4<-rbind(M3a,M3b,M3c,M3d)
rownames(M4)<-Groups
colnames(M4)<-colnames(M2[,3:7])
x<-as.data.frame(M4)


max1 <- rep(do.call("max", x),5)
min1 <- rep(do.call("min", x),5)

ploTData<- rbind(max1,min1,x)
colors_border=c(rgb(0,0,0,0.9), rgb(0.1,0.6,0.2,0.9), rgb(0.8,0.1,0.1,0.9), rgb(0.1,0.2,1,0.9))
colors_in=c(rgb(0,0,0,0.1), rgb(0.1,0.6,0.2,0.1), rgb(0.8,0.1,0.1,0.1), rgb(0.1,0.2,1,0.1))

pdf(paste0(pdir, "/radar.plot.liver.CD8_Fig3C.pdf"), width=5, height=5)
radarchart(ploTData, title = "CD8 T cells", pcol=colors_border, pfcol=colors_in, plwd=2, plty=1, cglcol="grey", cglty=1,cglwd=0.8)
dev.off()

##################Figure 3G RADAR PLOT tetramer########################

# Pex<-  list( c(sig1,sig2,sig3,sig4))
# Exhaustion<- list(c("Tox","Coch", "Crygb", "Cpa2", "Gdf3", "Klk6", "Myh4", "Scin", "Nptxr", "Cxcl10", "Spp1", "Dock7", "Trim47", "Spock2", "Tcea2", "Car2", "Chl1", "Rgs16", "Cpt2", "Ctla4", "Pdcd1",
#                     "Ptger2", "Plscr1", "Lag3", "Casp3", "Cd9", "Pawr", "Sh2d2a", "Gpd2", "Ndfip1", "Cd7", "Itgav", "Gas2", "Tcrg-V4", "Atf1", "Tor3a", "Tnfrsf1a"))

Effector<- list(c("Gzmb","Gzma","Prf1","Ifng","Tnf","Fasl"))
Pex<- list( c("Tbx21","Klrg1","Cx3cr1","Tcf7","Klf2","Sell"))
Exhaustion<- list(c("Pdcd1","Lag3","Ctla4","Havcr2","Tigit","Il10ra","Tox"))
IFNa_genes<- list(c("Stat1","Ly6c2","Oas1a","Irf8","Ifitm3") )
IFNg_genes<-list(c("Il18rap","Il18r1","Ifngas1","Il12rb1","Gbp2"))


tetramer.t<- AddModuleScore(tetramer.t, features = Effector, name = "Effector")
tetramer.t<- AddModuleScore(tetramer.t, features = Pex, name = "Pex")
tetramer.t<- AddModuleScore(tetramer.t, features = Exhaustion, name = "Exhaustion")
tetramer.t<- AddModuleScore(tetramer.t, features = IFNa_genes, name = "IFNa_genes")
tetramer.t<- AddModuleScore(tetramer.t, features = IFNg_genes, name = "IFNg_genes")


#Normalize data
#we needed to find a way to normalize the module scores. 
#we used a quantile normalization method.

M1<-tetramer.t@meta.data[,c("NewlablesM_clu", "RNA_Group", "Effector1","Pex1","Exhaustion1","IFNa_genes1","IFNg_genes1")]
#M1<-tetramer.t@meta.data[,c(41, 42, 60:64)]
M1[,3:7]<-limma::normalizeQuantiles(M1[,3:7])
Groups <-unique(tetramer.t$RNA_Group)
CellType<-unique(M1$NewlablesM_clu)

#with Median
#TAMs
#Groups are OVA.IL12 OVA.IFNa OVA Combo 
  M2<-M1
  M3a<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[1],3:7]),na.rm=T)
  M3b<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[2],3:7]),na.rm=T)
  M3c<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[3],3:7]),na.rm=T)
  M3d<-colMedians(as.matrix(M2[M2$RNA_Group%in%Groups[4],3:7]),na.rm=T)
  M4<-rbind(M3a,M3b,M3c,M3d)
  rownames(M4)<-Groups
  colnames(M4)<-colnames(M2[,3:7])
  x<-as.data.frame(M4)

  
max1 <- rep(do.call("max", x),5)
min1 <- rep(do.call("min", x),5)

ploTData<- rbind(max1,min1,x)
colors_border=c(rgb(0,0,0,0.9), rgb(0.1,0.6,0.2,0.9), rgb(0.8,0.1,0.1,0.9), rgb(0.1,0.2,1,0.9))
colors_in=c(rgb(0,0,0,0.1), rgb(0.1,0.6,0.2,0.1), rgb(0.8,0.1,0.1,0.1), rgb(0.1,0.2,1,0.1))


pdf(paste0(pdir, "/radar.plot.liver.tetramer_Fig3G.pdf"), width=5, height=5)
radarchart(ploTData, title = "OVA-reactive", pcol=colors_border, pfcol=colors_in, plwd=2, plty=1, cglcol="grey", cglty=1, cglwd=0.8)
dev.off()


