library(SingleCellExperiment)
library(dplyr)
library(ggplot2)
library(multinichenetr)

#####RELATIVE TO FIGURE 6H#########

#############Prepare files
wdir <- "/beegfs/scratch/ric.squadrito/ric.squadrito/90-935462466_scRNAseq_NotaroTAD_A019/Analysis_MM/results3/Result3_MNOT"
setwd(wdir)
all.labels <- readRDS("all.labels.rds")

#####open LIVER Obj
####Prepare files
username <- "C:/Users/notaro.marco/"
username <- "/Users/Squadrito/"
ddir<- paste0(username, "Dropbox (HSR Global)/90-935462466_scRNAseq_NotaroTAD_A019/Analysis_MM/results2cond/Tumor")
setwd(ddir)
obs <- readRDS("Tumor_final.rds")

obs@meta.data$NewlablesM2 <- all.labels[rownames(obs@meta.data)]
obs$sample_id <- paste0(obs$hash.ID, obs$PROP.Condition)


obs@meta.data$NewlablesG <- obs@meta.data$NewlablesM2
obs@meta.data$NewlablesG[grep("CD4",obs@meta.data$NewlablesM2) ] <- "CD4_Tcells"
obs@meta.data$NewlablesG[grep("CD8",obs@meta.data$NewlablesM2)] <- "CD8_Tcells"
obs@meta.data$NewlablesG[grep("DCs",obs@meta.data$NewlablesM2) ] <- "DCs"

###subset
sub.obj<-subset(obs,
                  subset= NewlablesG == "Macrophages"|
                  NewlablesG == "DCs"|
                  NewlablesG == "CD4_Tcells"|
                  NewlablesG == "CD8_Tcells")

#sub.obj2 <- subset(sub.obj,cells = sample(1:nrow(sub.obj@meta.data),500))
sub.obj2 <- sub.obj

nrow(sub.obj@meta.data)

###Multinichnet
organism = "mouse"
if(organism == "human"){
  lr_network = readRDS(url("https://zenodo.org/record/7074291/files/lr_network_human_21122021.rds"))
  lr_network = lr_network %>% dplyr::rename(ligand = from, receptor = to) %>% distinct(ligand, receptor) %>% mutate(ligand = make.names(ligand), receptor = make.names(receptor))
  ligand_target_matrix = readRDS(url("https://zenodo.org/record/7074291/files/ligand_target_matrix_nsga2r_final.rds"))
  colnames(ligand_target_matrix) = colnames(ligand_target_matrix) %>% make.names()
  rownames(ligand_target_matrix) = rownames(ligand_target_matrix) %>% make.names()
} else if(organism == "mouse"){
  lr_network = readRDS(url("https://zenodo.org/record/7074291/files/lr_network_mouse_21122021.rds"))
  lr_network = lr_network %>% dplyr::rename(ligand = from, receptor = to) %>% distinct(ligand, receptor) %>% mutate(ligand = make.names(ligand), receptor = make.names(receptor))
  ligand_target_matrix = readRDS(url("https://zenodo.org/record/7074291/files/ligand_target_matrix_nsga2r_final_mouse.rds"))
  colnames(ligand_target_matrix) = colnames(ligand_target_matrix) %>% make.names()
  rownames(ligand_target_matrix) = rownames(ligand_target_matrix) %>% make.names()
}


obs1 <- Seurat::as.SingleCellExperiment(sub.obj2, assay = "RNA")
obs1 = alias_to_symbol_SCE(obs1, "mouse") %>% makenames_SCE()


celltype_id = "NewlablesG"
group_id = "PROP.Condition"
sample_id = "sample_id"
covariates = NA
batches = NA

senders_oi = SummarizedExperiment::colData(obs1)[,celltype_id] %>% unique()
receivers_oi = SummarizedExperiment::colData(obs1)[,celltype_id] %>% unique()

min_cells = 10

abundance_expression_info = get_abundance_expression_info(sce = obs1, 
                    sample_id = sample_id, group_id = group_id, celltype_id = celltype_id, 
                    min_cells = min_cells, senders_oi = senders_oi, 
                    receivers_oi = receivers_oi, lr_network = lr_network, batches = batches)

abundance_expression_info$abund_plot_sample

contrasts_oi = c("'TA_combo-TA_only','TA_only-TA_combo'")

contrast_tbl = tibble(contrast = 
                        c("TA_combo-TA_only","TA_only-TA_combo"), 
                      group = c("TA_combo","TA_only"))

DE_info = get_DE_info(sce = obs1, sample_id = sample_id, 
                      group_id = group_id, celltype_id = celltype_id, 
                      batches = batches, covariates = covariates, 
                      contrasts_oi = contrasts_oi, min_cells = min_cells)


DE_info$celltype_de$de_output_tidy %>% arrange(p_adj) %>% head()

celltype_de = DE_info$celltype_de$de_output_tidy

sender_receiver_de = combine_sender_receiver_de(
  sender_de = celltype_de,
  receiver_de = celltype_de,
  senders_oi = senders_oi,
  receivers_oi = receivers_oi,
  lr_network = lr_network)

sender_receiver_de %>% head(20)

logFC_threshold = 0.50
p_val_threshold = 0.05
fraction_cutoff = 0.05

p_val_adj = FALSE 

top_n_target = 250

verbose = TRUE
#cores_system = 8
#n.cores = min(cores_system, sender_receiver_de$receiver %>% unique() %>% length()) # use one core per receiver cell type

#takes time

ligand_activities_targets_DEgenes = suppressMessages(suppressWarnings(get_ligand_activities_targets_DEgenes(
  receiver_de = celltype_de,
  receivers_oi = receivers_oi,
  ligand_target_matrix = ligand_target_matrix,
  logFC_threshold = logFC_threshold,
  p_val_threshold = p_val_threshold,
  p_val_adj = p_val_adj,
  top_n_target = top_n_target,
  verbose = verbose, 
  n.cores = 1
)))


#prioritazing
prioritizing_weights_DE = c("de_ligand" = 1,
                            "de_receptor" = 1)
prioritizing_weights_activity = c("activity_scaled" = 2)
prioritizing_weights_expression_specificity = c("exprs_ligand" = 2,
                                                "exprs_receptor" = 2)
prioritizing_weights_expression_sufficiency = c("frac_exprs_ligand_receptor" = 1)
prioritizing_weights_relative_abundance = c( "abund_sender" = 0,
                                             "abund_receiver" = 0)

prioritizing_weights = c(prioritizing_weights_DE, 
                         prioritizing_weights_activity, 
                         prioritizing_weights_expression_specificity,
                         prioritizing_weights_expression_sufficiency, 
                         prioritizing_weights_relative_abundance)

sender_receiver_tbl = sender_receiver_de %>% dplyr::distinct(sender, receiver)

metadata_combined = SummarizedExperiment::colData(obs1) %>% tibble::as_tibble()

#grouping
if(!is.na(batches)){
  grouping_tbl = metadata_combined[,c(sample_id, group_id, batches)] %>% tibble::as_tibble() %>% dplyr::distinct()
  colnames(grouping_tbl) = c("sample","group",batches)
} else {
  grouping_tbl = metadata_combined[,c(sample_id, group_id)] %>% tibble::as_tibble() %>% dplyr::distinct()
  colnames(grouping_tbl) = c("sample","group")}

#run it
prioritization_tables = suppressMessages(generate_prioritization_tables(
  sender_receiver_info = abundance_expression_info$sender_receiver_info,
  sender_receiver_de = sender_receiver_de,
  ligand_activities_targets_DEgenes = ligand_activities_targets_DEgenes,
  contrast_tbl = contrast_tbl,
  sender_receiver_tbl = sender_receiver_tbl,
  grouping_tbl = grouping_tbl,
  prioritizing_weights = prioritizing_weights,
  fraction_cutoff = fraction_cutoff, 
  abundance_data_receiver = abundance_expression_info$abundance_data_receiver,
  abundance_data_sender = abundance_expression_info$abundance_data_sender
))
prioritization_tables$group_prioritization_tbl %>% head(20)

##known info
lr_target_prior_cor = lr_target_prior_cor_inference(prioritization_tables$group_prioritization_tbl$receiver %>% unique(), abundance_expression_info, celltype_de, grouping_tbl, prioritization_tables, ligand_target_matrix, logFC_threshold = logFC_threshold, p_val_threshold = p_val_threshold, p_val_adj = p_val_adj)

##saving
multinichenet_output = list(
  celltype_info = abundance_expression_info$celltype_info,
  celltype_de = celltype_de,
  sender_receiver_info = abundance_expression_info$sender_receiver_info,
  sender_receiver_de =  sender_receiver_de,
  ligand_activities_targets_DEgenes = ligand_activities_targets_DEgenes,
  prioritization_tables = prioritization_tables,
  grouping_tbl = grouping_tbl,
  lr_target_prior_cor = lr_target_prior_cor
) 
multinichenet_output = make_lite_output(multinichenet_output)

seted(wdir)
saveRDS(multinichenet_output, paste0(wdir, "multinichenet_output.Tumor.19.rds"))
  

##look at top 50
prioritized_tbl_oi_all = get_top_n_lr_pairs(multinichenet_output$prioritization_tables, 50, rank_per_group = FALSE)

prioritized_tbl_oi = multinichenet_output$prioritization_tables$group_prioritization_tbl %>%
  filter(id %in% prioritized_tbl_oi_all$id) %>%
  distinct(id, sender, receiver, ligand, receptor, group) %>% left_join(prioritized_tbl_oi_all)
prioritized_tbl_oi$prioritization_score[is.na(prioritized_tbl_oi$prioritization_score)] = 0

senders_receivers = union(prioritized_tbl_oi$sender %>% unique(), prioritized_tbl_oi$receiver %>% unique()) %>% sort()

colors_sender = RColorBrewer::brewer.pal(n = length(senders_receivers), name = 'Spectral') %>% magrittr::set_names(senders_receivers)
colors_receiver = RColorBrewer::brewer.pal(n = length(senders_receivers), name = 'Spectral') %>% magrittr::set_names(senders_receivers)


circos_list = make_circos_group_comparison(prioritized_tbl_oi, colors_sender, colors_receiver)

##see interactions
group_oi = "TA_combo"

##plot results
prioritized_tbl_oi_M_50 = get_top_n_lr_pairs(multinichenet_output$prioritization_tables, 50, groups_oi = group_oi)

plot_oi = make_sample_lr_prod_activity_plots(multinichenet_output$prioritization_tables, prioritized_tbl_oi_M_50)
plot_oi

##see interactions
group_oi = "TA_only"

##plot results
prioritized_tbl_oi_M_50 = get_top_n_lr_pairs(multinichenet_output$prioritization_tables, 50, groups_oi = group_oi)

plot_oi = make_sample_lr_prod_activity_plots(multinichenet_output$prioritization_tables, prioritized_tbl_oi_M_50)
plot_oi

sessionInfo()


