library(openxlsx)
library(dplyr)
library(readxl)
library(psych)
library(data.table)
library(GGally)
library(ggplot2)
library(ggpubr)
library(ggrepel)

#WDs
MNOT.gar<-"C:/Users/notaro.marco/Dropbox (HSR Global)/90-756147447_WES_Squadrito/WES_07-diff_GRCm38/"
MNOT.pvac<-"C:/Users/notaro.marco/Dropbox (HSR Global)/90-756147447_WES_Squadrito/WES_07-diff_GRCm38/pvacseq_mouse/MHC_Class_I"
MNOT.wd1<-"C:/Users/notaro.marco/Dropbox (HSR Global)/90-756142658_RNAseq_Squadrito/03-aln_GRCm38/"


#WD MLS
#MNOT.gar<-"/Users/Squadrito/Dropbox (HSR Global)/90-756147447_WES_Squadrito/WES_07-diff_GRCm38"
#MNOT.pvac<-"/Users/Squadrito/Dropbox (HSR Global)/90-756147447_WES_Squadrito/WES_07-diff_GRCm38/pvacseq_mouse/MHC_Class_I"
#MNOT.wd1<-"/Users/Squadrito/Dropbox (HSR Global)/90-756142658_RNAseq_Squadrito/03-aln_GRCm38"




#define filtering functions

filter_data_common <- function(df, a1, a2, a3, a4, a5, a6, a7, a8) {
  subset(df, (Ensemble_score <= a1 | is.na(Ensemble_score)) &
           (IC50.MT <= a2 | is.na(IC50.MT)) &
           (DAI >= a3 | is.na(DAI)) &
           (agretopicity <= a4 | is.na(agretopicity)) &
           (average_vivo >= a5 | is.na(average_vivo)) &
           (average_vitro >= a6 | is.na(average_vitro)) &
           (dissimilarity >= a7 | is.na(dissimilarity)) &
           (foreignness_score >= a8 | is.na(foreignness_score)))
}

filter_data_garnish <- function(df, a1, a3, a5, a6, a7, a8) {
  subset(df, (Ensemble_score <= a1 | is.na(Ensemble_score)) &
           (DAI >= a3 | is.na(DAI)) &
           (average_vivo >= a5 | is.na(average_vivo)) &
           (average_vitro >= a6 | is.na(average_vitro)) &
           (dissimilarity >= a7 | is.na(dissimilarity)) &
           (foreignness_score >= a8 | is.na(foreignness_score)))
}


filter_data_pvac <- function(df, a2, a4, a5, a6, a7, a8) {
  subset(df,(IC50.MT <= a2 | is.na(IC50.MT)) &
            (agretopicity <= a4 | is.na(agretopicity)) &
            (average_vivo >= a5 | is.na(average_vivo)) &
            (average_vitro >= a6 | is.na(average_vitro)) &
            (dissimilarity >= a7 | is.na(dissimilarity)) &
            (foreignness_score >= a8 | is.na(foreignness_score)))
}




##Garnish
#carica la tabella di antigengarnish
setwd(MNOT.gar)
data_garnish<- fread("ant_garnish_res_AKTPFV3only_filt_coding.tsv", sep = "\t", header = TRUE)

###pvac 
setwd(MNOT.pvac)
data_pvac <- read_excel("pvac_seq.xlsx")

#Common
common.pep.pvac<-unique(data_pvac$Best.Peptide)
common.pep.garnish<-unique(data_garnish$nmer)
common.pep<-intersect(common.pep.pvac,common.pep.garnish)

data_pvac2<-subset(data_pvac,Best.Peptide%in%common.pep)
data_pvac3<-data_pvac2 %>%
  group_by(Best.Peptide) %>%
  slice(which.min(IC50.MT))

data_garnish2<-subset(data_garnish,nmer%in%common.pep)
data_garnish3<-data_garnish2 %>%
  group_by(nmer_uuid) %>%
  slice(which.min(Ensemble_score))

data.common<-merge(data_pvac3,data_garnish3, by.x = "Best.Peptide", by.y= "nmer")


#ADD expression
setwd(MNOT.wd1)
count_tpm <- read_excel("featureCounts_results_tpm.xlsx")

#average expression level to pply filtering
count_tpm$average_vitro<-apply(count_tpm[,7:9],1,function(x)mean(x))
#sum(count_tpm$average_vitro==0)
count_tpm$average_vitro[apply(count_tpm[,7:9],1,function(x)mean(x)*min(x))==0]<-0

count_tpm$average_vivo<-apply(count_tpm[,10:12],1,function(x)mean(x))
#sum(count_tpm$average_vivo==0)
count_tpm$average_vivo[apply(count_tpm[,10:12],1,function(x)mean(x)*min(x))==0]<-0


merged.exp<-merge(data.common,count_tpm[,c("Geneid","average_vivo","average_vitro")], by.x = "Gene",by.y="Geneid")
merged.df<-merged.exp #1244

merged.df[,c(22)]<-as.numeric(as.character(merged.df[,c(22)]))
merged.df[,c(24)]<-as.numeric(as.character(merged.df[,c(24)]))
merged.df$dissimilarity.x[is.na(merged.df$dissimilarity.x)] <- 0
merged.df$foreignness_score.x[is.na(merged.df$foreignness_score.x)] <- 0
merged.df$dissimilarity<-merged.df$dissimilarity.x
merged.df$foreignness_score<-merged.df$foreignness_score.x



#FILTERING common based on expr and foreigness
a1<-quantile(merged.df$Ensemble_score, 0.2) #minor 0.4
a2<-quantile(merged.df$IC50.MT, 1) #minor 0.4
a3<-quantile(merged.df$DAI, 0,na.rm=T) #higher 0.4
a4<-quantile(merged.df$agretopicity, 1) #minor 0.6
a5<-quantile(merged.df$average_vivo, 0.80) #higher 90
a6<-quantile(merged.df$average_vitro, 0.90)  #higher 95
a7<-quantile(merged.df$dissimilarity, 0)  #higher 
a8<-quantile(merged.df$foreignness_score, 0.5)  #higher 


data_filter1<-filter_data_common(merged.df,a1,a2,a3,a4,a5,a6,a7,a8)
  

db1 <- data_filter1[,c(1,2,3,6,10,11,131,12,132,138,139,140,141)]
db1$type <- "exp-foreigness"
db1

#FILTERING common based on IC50,Agretopicity

a1<-quantile(merged.df$Ensemble_score, 0.12) #minor
a2<-quantile(merged.df$IC50.MT, 0.12) #minor
a3<-quantile(merged.df$DAI, 0.2,na.rm=T) #higher
a4<-quantile(merged.df$agretopicity, 0.1) #minor
a5<-quantile(merged.df$average_vivo, 0.50) #higher
a6<-quantile(merged.df$average_vitro, 0.60)  #higher
a7<-quantile(merged.df$dissimilarity, 0)  #higher
a8<-quantile(merged.df$foreignness_score, 0.0)  #higher

data_filter2<-filter_data_common(merged.df,a1,a2,a3,a4,a5,a6,a7,a8)

db2 <- data_filter2[,c(1,2,3,6,10,11,131,12,132,138,139,140,141)]
db2$type <- "IC50-agretopicity"
db2

#FILTERING common based on expression and IC50

a1<-quantile(merged.df$Ensemble_score, 0.3) #minor
a2<-quantile(merged.df$IC50.MT, 0.3) #minor
a3<-quantile(merged.df$DAI, 0.4,na.rm=T) #higher
a4<-quantile(merged.df$agretopicity, 0.6) #minor
a5<-quantile(merged.df$average_vivo, 0.90) #higher
a6<-quantile(merged.df$average_vitro, 0.95)  #higher
a7<-quantile(merged.df$dissimilarity, 0)  #higher
a8<-quantile(merged.df$foreignness_score, 0.0)  #higher

data_filter3<-filter_data_common(merged.df,a1,a2,a3,a4,a5,a6,a7,a8)

db3 <- data_filter3[,c(1,2,3,6,10,11,131,12,132,138,139,140,141)]
db3$type <- "IC50-exp" 
db3

common.sel<- rbind(db1,db2,db3)
common.sel<-common.sel %>% group_by(Best.Peptide) %>%
  slice(which.min(Ensemble_score))

#top scoring in garnish
#take only garnish not present in common
garnish.only<- subset(data_garnish, !(nmer %in% common.pep))

#ADD expression
garnish.only<-merge(garnish.only,count_tpm[,c("Geneid",
          "average_vivo","average_vitro")], by.x = "gene",by.y="Geneid")

#rimuovi peptidi wt,più lunghi di 10aa, multipli e di frame diversi, tiene solo quelli con ensemble score piu alto
garnish.only<- subset(garnish.only, pep_type != "wt")
garnish.only<-subset(garnish.only, nmer_l<= 10 )

garnish.only<-garnish.only %>%
  group_by(nmer_uuid) %>%
  slice(which.min(Ensemble_score))

garnish.only <- garnish.only %>%
  group_by(var_uuid) %>%
  slice(which.min(Ensemble_score))

garnish.only$foreignness_score[is.na(garnish.only$foreignness_score)]<-0

#FILTERING garnish based on Enseble score
a1<-quantile(garnish.only$Ensemble_score, 0.01) #minor
a3<-quantile(garnish.only$DAI, 0.5,na.rm=T) #higher
a5<-quantile(garnish.only$average_vivo, 0.40) #higher
a6<-quantile(garnish.only$average_vitro, 0.40)  #higher
a7<-quantile(garnish.only$dissimilarity, 0 ,na.rm=T )  #higher
a8<-quantile(garnish.only$foreignness_score, .8,na.rm=T )  #higher


data_filter1<-filter_data_garnish(garnish.only,a1,a3,a5,a6,a7,a8)
db1<-data_filter1[,c(1,2,9,10,12,13,57,108,109,111,113,115,116)]
db1$type <- "Escore" 

#FILTERING garnish based on expression
a1<-quantile(garnish.only$Ensemble_score, 0.1) #minor
a3<-quantile(garnish.only$DAI, 0.5,na.rm=T) #higher
a5<-quantile(garnish.only$average_vivo, 0.90) #higher
a6<-quantile(garnish.only$average_vitro, 0.95)  #higher
a7<-quantile(garnish.only$dissimilarity, 0 ,na.rm=T )  #higher
a8<-quantile(garnish.only$foreignness_score, .8,na.rm=T )  #higher


data_filter2<-filter_data_garnish(garnish.only,a1,a3,a5,a6,a7,a8)
db2<-data_filter2[,c(1,2,9,10,12,13,57,108,109,111,113,115,116)]
db2$type <- "expression" 


garnish.sel<- rbind(db1,db2)
garnish.sel<-garnish.sel %>% group_by(nmer) %>%
  slice(which.min(Ensemble_score))

#top scoring in pvac
#take only pvac not present in common
pvac.only<- subset(data_pvac, !(Best.Peptide %in% common.pep))

#ADD expression
pvac.only<-merge(pvac.only,count_tpm[,c("Geneid",
            "average_vivo","average_vitro")], by.x = "Gene",by.y="Geneid")

pvac.only$nmer_l<-nchar(pvac.only$Best.Peptide)

pvac.only$foreignness_score<-as.numeric(pvac.only$foreignness_score)
pvac.only$foreignness_score[is.na(pvac.only$foreignness_score)]<-0



#FILTERING pvac based on IC50 
a2<-quantile(pvac.only$IC50.MT, 0.2) #minor
a4<-quantile(pvac.only$agretopicity, 0.2) #minor
a5<-quantile(pvac.only$average_vivo, 0.2) #higher
a6<-quantile(pvac.only$average_vitro, 0.2)  #higher
a7<-quantile(pvac.only$dissimilarity, 0)  #higher
a8<-quantile(pvac.only$foreignness_score, 0)  #higher

data_filter1<-filter_data_pvac(pvac.only,a2,a4,a5,a6,a7,a8)
db1<-data_filter1[,c(1,2,3,6,10,11,25,26,22,24)]

db1$type <- "IC50" 

#FILTERING pvac based on expression

a2<-quantile(pvac.only$IC50.MT, .5) #minor
a4<-quantile(pvac.only$agretopicity, 1) #minor
a5<-quantile(pvac.only$average_vivo, 0.80) #higher
a6<-quantile(pvac.only$average_vitro, 0.90)  #higher
a7<-quantile(pvac.only$dissimilarity, 0)  #higher
a8<-quantile(pvac.only$foreignness_score, 0)  #higher

data_filter2<-filter_data_pvac(pvac.only,a2,a4,a5,a6,a7,a8)
db2<-data_filter2[,c(1,2,3,6,10,11,25,26,22,24)]
db2$type <- "exp" 


pvac.sel<- rbind(db1,db2)

pvac.sel<-pvac.sel %>%
  group_by(Best.Peptide) %>%
  slice(which.min(IC50.MT))

#length of nmer in original db
windows()
par(mfrow=c(3,1))
hist(garnish.only$nmer_l,xlim=c(8,12))
hist(merged.df$nmer_l,xlim=c(8,12))
hist(pvac.only$nmer_l,xlim=c(8,12))

#length of selected nmer
pvac.sel$nmer_l<-nchar(pvac.sel$Best.Peptide)
common.sel$nmer_l<-nchar(common.sel$Best.Peptide)
garnish.sel$nmer_l<-nchar(garnish.sel$nmer)

windows()
par(mfrow=c(3,1))
hist(garnish.sel$nmer_l,xlim=c(8,12))
hist(common.sel$nmer_l,xlim=c(8,12))
hist(pvac.sel$nmer_l,xlim=c(8,12))


#FINAL MERGE of selected adding origin

common.sel$origin<-"common"
garnish.sel$origin<-"garnish"
pvac.sel$origin<-"pvac"

colnames(common.sel)[1:3]<-c("gene","nmer","ID")
colnames(pvac.sel)[c(1,2)]<-c("gene","nmer")

db.All <- merge(garnish.sel,merge(common.sel,pvac.sel,all=TRUE),all=T)


# Crea un nuovo file Excel e salva il dataframe 
setwd(MNOT.gar)
write.xlsx(db.All,"FinalTable.xlsx")


#########################################################################################
#####################ENDS HERE###########################################################
###########################################################################################
















#plots

FINAL_LIST_PEP <- read_excel("C:/Users/notaro.marco/Dropbox (HSR Global)/90-756147447_WES_Squadrito/WES_07-diff_GRCm38/FINAL_LIST_PEP.xlsx")



windows()
par(mfrow=c(4,2))
db.ES<- FINAL_LIST_PEP[!is.na(FINAL_LIST_PEP$Ensemble_score),]
plot.ecdf((merged.df$Ensemble_score),main="Ensemble_score", xlab=(""))
abline(v=(FINAL_LIST_PEP$Ensemble_score),col="red")

db.ES<- FINAL_LIST_PEP[!is.na(FINAL_LIST_PEP$IC50.MT),]
plot.ecdf((merged.df$IC50.MT),main="IC50.MT", xlab=(""))
abline(v=(FINAL_LIST_PEP$IC50.MT),col="red")

db.ES<- FINAL_LIST_PEP[!is.na(FINAL_LIST_PEP$foreignness_score),]
plot.ecdf(merged.df$foreignness_score,main="foreigness_score", xlab=(""))
abline(v=FINAL_LIST_PEP$foreignness_score,col="red")

#db.ES<- FINAL_LIST_PEP[!is.na(FINAL_LIST_PEP$DAI),]
#plot.ecdf((merged.df$DAI+0.1),main="DAI")
#abline(v=(db.ES$DAI+0.1),col="red")

db.ES<- FINAL_LIST_PEP[!is.na(FINAL_LIST_PEP$agretopicity),]
plot.ecdf((merged.df$agretopicity+0.01),main="agretopicity", xlab=(""))
abline(v=(FINAL_LIST_PEP$agretopicity+0.01),col="red")

db.ES<- FINAL_LIST_PEP[!is.na(FINAL_LIST_PEP$average_vitro),]
plot.ecdf((merged.df$average_vitro+0.00001),main="average_vitro", xlab=(""))
abline(v=(FINAL_LIST_PEP$average_vitro+0.00001),col="red")

db.ES<- FINAL_LIST_PEP[!is.na(FINAL_LIST_PEP$average_vivo),]
plot.ecdf((merged.df$average_vivo+0.00001),main="average_vivo", xlab=(""))
abline(v=(FINAL_LIST_PEP$average_vivo+0.00001),col="red")

#gg plots

windows()
par(mfrow=c(2,2))

p<- ggplot(merged.df, aes(IC50.MT)) +
  geom_line(stat = "ecdf")+
  geom_point(stat="ecdf",size=2) +
  geom_vline(xintercept=FINAL_LIST_PEP$IC50.MT, colour = "red")
p


#histos

windows()
par(mfrow=c(2,2))

hist(merged.df$IC50.MT, breaks = 100, xlab="IC50", main ="IC50")
abline(v=(FINAL_LIST_PEP$IC50.MT),col="black")


hist(log10(merged.df$average_vivo), breaks = 100, xlab="Average expression (log TPM)", main ="Log TPM")
abline(v=(log10(FINAL_LIST_PEP$average_vivo)),col="black")

hist(merged.df$agretopicity, xlab="Agretopicity", main ="Agretopicity")
abline(v=(FINAL_LIST_PEP$agretopicity),col="red")

hist(merged.df$foreignness_score, xlab="Foreigness", main ="Foreigness")
abline(v=(FINAL_LIST_PEP$foreignness_score),col="red")


#corr
windows()
par(mfrow=c(2,2))
p<-ggscatter(merged.df, x = "IC50.MT", y = "average_vivo", 
          cor.coef = TRUE, cor.method = "pearson",
          xlab = "IC50", ylab = "log10 TPM",
          color= "black", fill='grey', shape=21, size=5)+
            scale_y_log10()+
  scale_x_log10()+
  geom_vline(xintercept=1000, colour = "red",linetype = "dashed")+
  geom_hline(yintercept=10, colour = "red",linetype = "dashed")+
  geom_point(data=FINAL_LIST_PEP, fill= "green",color="black", , shape=21, size=5)+
  grids(linetype = "dashed")+
  geom_text_repel(
    data = FINAL_LIST_PEP,
    aes(label = gene),
    size = 5,
    box.padding = unit(0.35, "lines"),
    point.padding = unit(0.3, "lines")
  )
p


windows()
par(mfrow=c(2,2))
p<-ggscatter(merged.df, x = "foreignness_score", y = "agretopicity", 
             cor.coef = TRUE, cor.method = "pearson",
             xlab = "Foreigness", ylab = "Agretopicity",
             color= "black", fill='grey', shape=21, size=5)+
  scale_y_log10()+
  scale_x_log10()+
  geom_point(data=FINAL_LIST_PEP, fill= "green",color="black", , shape=21, size=5)+
  grids(linetype = "dashed")+ 
  geom_text_repel(
    data = FINAL_LIST_PEP,
    aes(label = gene),
    size = 5,
    box.padding = unit(0.35, "lines"),
    point.padding = unit(0.3, "lines")
  )
p  
  


