library(openxlsx)
library(dplyr)
library(readxl)
library(psych)
library(data.table)
library(tidyr)
library(stringr)
library(R.utils)

#WDs
MNOT.gar<-"C:/Users/notaro.marco/Dropbox (HSR Global)/90-756147447_WES_Squadrito/WES_07-diff_GRCm38/"
MNOT.pvac<-"C:/Users/notaro.marco/Dropbox (HSR Global)/90-756147447_WES_Squadrito/WES_07-diff_GRCm38/pvacseq_mouse/MHC_Class_I"
MNOT.wd1<-"C:/Users/notaro.marco/Dropbox (HSR Global)/90-756142658_RNAseq_Squadrito/03-aln_GRCm38/"

#MLS
MNOT.gar<-"/Users/Squadrito/Dropbox (HSR Global)/90-756147447_WES_Squadrito/WES_07-diff_GRCm38"
MNOT.pvac<-"/Users/Squadrito/Dropbox (HSR Global)/90-756147447_WES_Squadrito/WES_07-diff_GRCm38/pvacseq_mouse/MHC_Class_I"
MNOT.wd1<-"/Users/Squadrito/Dropbox (HSR Global)/90-756142658_RNAseq_Squadrito/03-aln_GRCm38"

mappa_completa <- c("Ala" = "A", "Arg" = "R", "Asn" = "N", "Asp" = "D", "Cys" = "C", 
                    "Gln" = "Q", "Glu" = "E", "Gly" = "G", "His" = "H", "Ile" = "I", 
                    "Leu" = "L", "Lys" = "K", "Met" = "M", "Phe" = "F", "Pro" = "P", 
                    "Ser" = "S", "Thr" = "T", "Trp" = "W", "Tyr" = "Y", "Val" = "V")

##Garnish
#carica la tabella di antigengarnish
#setwd(MNOT.gar)
#data_garnish<- fread("ant_garnish_res_AKTPFV3only_filt_coding.tsv.gz", sep = "\t", header = TRUE)

#clean garnish
#data_garnish<-subset(data_garnish, effect_type == "missense_variant")
#data_garnish<- subset(data_garnish, pep_type != "wt")
#saveRDS(data_garnish,"data_garnish.rds")
data_garnish<-readRDS("data_garnish.rds")


#create protein_pos column
data_garnish <- separate(data_garnish, Protein_position_Protein_len, 
                         into = c("Protein_pos", "Protein_length"), sep = "/")
data_garnish$Protein_pos<-as.numeric(as.character(data_garnish$Protein_pos))


#calculate distance from previous mutation in the same gene, take only mutation that are nearby in the protein (distance<10)
data_garnish2<-data_garnish[,c(50,7,60,57,67)]
data_garnish2 <- unique(data_garnish2)
double_mut <- data_garnish2[order(data_garnish2$transcript_id, data_garnish2$Protein_pos),]
double_mut$next_position1 <- c(double_mut$Protein_pos[-1],NA)
double_mut$next_gene1 <- c(double_mut$transcript_id[-1],NA)
double_mut$next_mut1 <- c(double_mut$protein_change[-1],NA)
double_mut$distance1 <- ifelse(double_mut$transcript_id == double_mut$next_gene1, 
                            double_mut$next_position1-double_mut$Protein_pos, NA)

#genes with 3 concatenate mutations
df1<-double_mut
remove_rows<- c(-1,-2)
df2<- df1[order(df1$transcript_id, df1$Protein_pos),]
df2$next_position2 <- c(df2$Protein_pos[remove_rows],NA,NA)
df2$next_gene2 <- c(df2$transcript_id[remove_rows],NA,NA)
df2$next_mut2 <- c(df2$protein_change[remove_rows],NA,NA)
df2$distance2 <- ifelse(df2$transcript_id == df2$next_gene2, 
                        df2$next_position2 - df2$Protein_pos, NA)

#transcripts with 4 concatenate mutations
remove_rows<- c(-1,-2,-3)
df3<- df2[order(df2$transcript_id, df2$Protein_pos),]
df3$next_position3 <- c(df2$Protein_pos[remove_rows],NA,NA,NA)
df3$next_gene3 <- c(df2$transcript_id[remove_rows],NA,NA,NA)
df3$next_mut3 <- c(df2$protein_change[remove_rows],NA,NA,NA)
df3$distance3 <- ifelse(df3$transcript_id == df3$next_gene3, 
                       df3$next_position3 - df3$Protein_pos, NA)

#transcripts with 5 concatenate mutations
remove_rows<- c(-1,-2,-3,-4)
df4<- df3[order(df3$transcript_id, df3$Protein_pos),]
df4$next_position4 <- c(df3$Protein_pos[remove_rows],NA,NA,NA,NA)
df4$next_gene4 <- c(df3$transcript_id[remove_rows],NA,NA,NA,NA)
df4$next_mut4 <- c(df3$protein_change[remove_rows],NA,NA,NA,NA)
df4$distance4 <- ifelse(df4$transcript_id == df4$next_gene4, 
                        df4$next_position4 - df4$Protein_pos, NA)

#Apply filters
pep01 <- df4 %>% filter(distance1 <= 10 & distance1 >0 &
                  (is.na(distance2)|distance2>10|
                   (distance2==distance1 & (is.na(distance3)|distance3>10))))

pep02 <- df4 %>% filter(distance1 == 0 & distance2 <= 10 & distance2 > 0 &
                  (is.na(distance3)|distance3 > 10|
                    (distance3 == distance2 & (is.na(distance4)|distance4 > 10))))

pep012 <- df4 %>% filter(distance1 <= 10 & distance1 >0 &
                      distance2 <= 10 & distance2 >0 &
                        distance1!=distance2 &
                          (is.na(distance3)|distance3>10|
                             (distance3==distance2 & (is.na(distance4)|distance4>10))))

pep013 <- df4 %>% filter(distance1 <= 10 & distance1 >0 &
                           distance1==distance2 &
                            distance3 <= 10 & distance3 >0 &
                             (is.na(distance4)|distance4>10|distance4==distance3))

pep0123 <- df4 %>% filter(distance1 <= 10 & distance1 >0 &
                            distance1!=distance2 &
                        distance2 <= 10 & distance2 >0 &
                          distance2!=distance3 &
                          distance3 <= 10 & distance3 >0 &
                           (is.na(distance4)|distance4>10|distance4==distance3))

#Select columns for semplicity
pep01 <- pep01[,c(1,2,3,5,4,8)]
pep02 <- pep02[,c(1,2,3,5,4,12)]
pep012 <- pep012[,c(1,2,3,5,4,8,12)]
pep013<- pep013[,c(1,2,3,5,4,8,16)]
pep0123 <- pep0123[,c(1,2,3,5,4,8,12,16)]

#crea colonne con la singola mutazione e converte in codice ad una lettera
#for 
Create_db <- function(dfi,x,name.pep="pep"){
Prot_mut <- dfi[,4]
  for (i in x){
  aminoacido_sost <- str_extract(dfi[,i], "(?<=\\d)[A-Z][a-z]{2}")
  pos_inMut <- as.numeric(as.character(str_sub(dfi[,i], 6, -4)))
  aminoacido_sost <- mappa_completa[aminoacido_sost]
  Prot_mut<- transform(str_replace(Prot_mut, paste0("^(.{", pos_inMut-1, "})."), paste0("\\1", aminoacido_sost)))
  Prot_mut <- Prot_mut[,1]} 
  Pep_mut <- substr(Prot_mut, dfi[,3]-9, dfi[,3]+10)
  Pep_wt <- substr(dfi[,4], dfi[,3]-9, dfi[,3]+10)
  Gene_ID <- paste0(dfi[,1],name.pep)
  mut0123<- data.frame(Gene_ID,Pep_wt,Pep_mut)
      return(mut0123)}

pep01 <- pep01[,c(1,2,3,5,4,8)]
pep02 <- pep02[,c(1,2,3,5,4,12)]
pep012 <- pep012[,c(1,2,3,5,4,8,12)]
pep013<- pep013[,c(1,2,3,5,4,8,16)]
pep0123 <- pep0123[,c(1,2,3,5,4,8,12,16)]

FinalDB <- rbind(Create_db(pep01,5:6,".01"),
                 Create_db(pep02,5:6,".02"),
                 Create_db(pep012,5:7,".012"),
                 Create_db(pep013,5:7,".013"),
                 Create_db(pep0123,5:8,".0123"))

FinalDB <- unique(FinalDB)
write.xlsx(FinalDB,"multipleMuts_MNOT.xlsx")
  
  